@@ -35,7 +35,7 @@
  * is done in another thread than the application.
  *
  * The GstBus provides support for #GSource based notifications. This makes it
- * possible to handle the delivery in the glib mainloop.
+ * possible to handle the delivery in the glib #GMainLoop.
  *
  * The #GSource callback function gst_bus_async_signal_func() can be used to
  * convert all bus messages into signal emissions.
@@ -73,7 +73,7 @@
 #endif
 #include <sys/types.h>
 
-#include "gstatomicqueue.h"
+#include "gstvecdeque.h"
 #include "gstinfo.h"
 #include "gstpoll.h"
 
@@ -97,6 +97,7 @@ enum
 };
 
 #define DEFAULT_ENABLE_ASYNC (TRUE)
+#define WARN_QUEUE_SIZE 1024
 
 enum
 {
@@ -139,15 +140,15 @@ sync_handler_unref (SyncHandler * handler)
 
 struct _GstBusPrivate
 {
-  GstAtomicQueue *queue;
   GMutex queue_lock;
+  GstVecDeque *queue;
 
   SyncHandler *sync_handler;
 
   guint num_signal_watchers;
 
   guint num_sync_message_emitters;
-  GSource *signal_watch;
+  GSource *gsource;
 
   gboolean enable_async;
   GstPoll *poll;
@@ -197,9 +198,9 @@ gst_bus_class_init (GstBusClass * klass)
   gobject_class->constructed = gst_bus_constructed;
 
   /**
-   * GstBus::enable-async:
+   * GstBus:enable-async:
    *
-   * Enable async message delivery support for bus watches,
+   * Enables async message delivery support for bus watches,
    * gst_bus_pop() and similar API. Without this only the
    * synchronous message handlers are called.
    *
@@ -214,7 +215,7 @@ gst_bus_class_init (GstBusClass * klass)
 
   /**
    * GstBus::sync-message:
-   * @bus: the object which received the signal
+   * @self: the object which received the signal
    * @message: the message that has been posted synchronously
    *
    * A message has been posted on the bus. This signal is emitted from the
@@ -227,22 +228,22 @@ gst_bus_class_init (GstBusClass * klass)
       g_signal_new ("sync-message", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
       G_STRUCT_OFFSET (GstBusClass, sync_message), NULL, NULL,
-      g_cclosure_marshal_generic, G_TYPE_NONE, 1, GST_TYPE_MESSAGE);
+      NULL, G_TYPE_NONE, 1, GST_TYPE_MESSAGE);
 
   /**
    * GstBus::message:
-   * @bus: the object which received the signal
+   * @self: the object which received the signal
    * @message: the message that has been posted asynchronously
    *
    * A message has been posted on the bus. This signal is emitted from a
-   * GSource added to the mainloop. this signal will only be emitted when
-   * there is a mainloop running.
+   * #GSource added to the mainloop. this signal will only be emitted when
+   * there is a #GMainLoop running.
    */
   gst_bus_signals[ASYNC_MESSAGE] =
       g_signal_new ("message", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
       G_STRUCT_OFFSET (GstBusClass, message), NULL, NULL,
-      g_cclosure_marshal_generic, G_TYPE_NONE, 1, GST_TYPE_MESSAGE);
+      NULL, G_TYPE_NONE, 1, GST_TYPE_MESSAGE);
 }
 
 static void
@@ -251,7 +252,7 @@ gst_bus_init (GstBus * bus)
   bus->priv = gst_bus_get_instance_private (bus);
   bus->priv->enable_async = DEFAULT_ENABLE_ASYNC;
   g_mutex_init (&bus->priv->queue_lock);
-  bus->priv->queue = gst_atomic_queue_new (32);
+  bus->priv->queue = gst_vec_deque_new (32);
 
   GST_DEBUG_OBJECT (bus, "created");
 }
@@ -266,11 +267,11 @@ gst_bus_dispose (GObject * object)
 
     g_mutex_lock (&bus->priv->queue_lock);
     do {
-      message = gst_atomic_queue_pop (bus->priv->queue);
+      message = gst_vec_deque_pop_head (bus->priv->queue);
       if (message)
         gst_message_unref (message);
     } while (message != NULL);
-    gst_atomic_queue_unref (bus->priv->queue);
+    gst_vec_deque_free (bus->priv->queue);
     bus->priv->queue = NULL;
     g_mutex_unlock (&bus->priv->queue_lock);
     g_mutex_clear (&bus->priv->queue_lock);
@@ -320,12 +321,10 @@ gst_bus_new (void)
  * @bus: a #GstBus to post on
  * @message: (transfer full): the #GstMessage to post
  *
- * Post a message on the given bus. Ownership of the message
+ * Posts a message on the given bus. Ownership of the message
  * is taken by the bus.
  *
  * Returns: %TRUE if the message could be posted, %FALSE if the bus is flushing.
- *
- * MT safe.
  */
 gboolean
 gst_bus_post (GstBus * bus, GstMessage * message)
@@ -367,10 +366,13 @@ gst_bus_post (GstBus * bus, GstMessage * message)
 
   g_clear_pointer (&sync_handler, sync_handler_unref);
 
-  /* If this is a bus without async message delivery
-   * always drop the message */
-  if (!bus->priv->poll)
+  /* If this is a bus without async message delivery always drop the message.
+   * If the sync handler returned GST_BUS_DROP it is responsible of unreffing
+   * the message, otherwise do it ourself. */
+  if (!bus->priv->poll && reply != GST_BUS_DROP) {
     reply = GST_BUS_DROP;
+    gst_message_unref (message);
+  }
 
   /* now see what we should do with the message */
   switch (reply) {
@@ -378,14 +380,25 @@ gst_bus_post (GstBus * bus, GstMessage * message)
       /* drop the message */
       GST_DEBUG_OBJECT (bus, "[msg %p] dropped", message);
       break;
-    case GST_BUS_PASS:
+    case GST_BUS_PASS:{
+      g_mutex_lock (&bus->priv->queue_lock);
+      gsize length = gst_vec_deque_get_length (bus->priv->queue);
+      if (G_UNLIKELY (length > 0 && length % WARN_QUEUE_SIZE == 0)) {
+        GST_WARNING_OBJECT (bus,
+            "queue overflows with %" G_GSIZE_FORMAT " messages. "
+            "Application is too slow or is not handling messages. "
+            "Please add a message handler, otherwise the queue will grow "
+            "infinitely.", length);
+      }
       /* pass the message to the async queue, refcount passed in the queue */
       GST_DEBUG_OBJECT (bus, "[msg %p] pushing on async queue", message);
-      gst_atomic_queue_push (bus->priv->queue, message);
+      gst_vec_deque_push_tail (bus->priv->queue, message);
       gst_poll_write_control (bus->priv->poll);
       GST_DEBUG_OBJECT (bus, "[msg %p] pushed on async queue", message);
+      g_mutex_unlock (&bus->priv->queue_lock);
 
       break;
+    }
     case GST_BUS_ASYNC:
     {
       /* async delivery, we need a mutex and a cond to block
@@ -405,8 +418,10 @@ gst_bus_post (GstBus * bus, GstMessage * message)
        * the cond will be signalled and we can continue */
       g_mutex_lock (lock);
 
-      gst_atomic_queue_push (bus->priv->queue, message);
+      g_mutex_lock (&bus->priv->queue_lock);
+      gst_vec_deque_push_tail (bus->priv->queue, message);
       gst_poll_write_control (bus->priv->poll);
+      g_mutex_unlock (&bus->priv->queue_lock);
 
       /* now block till the message is freed */
       g_cond_wait (cond, lock);
@@ -426,6 +441,7 @@ gst_bus_post (GstBus * bus, GstMessage * message)
     }
     default:
       g_warning ("invalid return from bus sync handler");
+      gst_message_unref (message);
       break;
   }
   return TRUE;
@@ -445,13 +461,11 @@ is_flushing:
  * gst_bus_have_pending:
  * @bus: a #GstBus to check
  *
- * Check if there are pending messages on the bus that
+ * Checks if there are pending messages on the bus that
  * should be handled.
  *
  * Returns: %TRUE if there are messages on the bus to be handled, %FALSE
  * otherwise.
- *
- * MT safe.
  */
 gboolean
 gst_bus_have_pending (GstBus * bus)
@@ -461,7 +475,9 @@ gst_bus_have_pending (GstBus * bus)
   g_return_val_if_fail (GST_IS_BUS (bus), FALSE);
 
   /* see if there is a message on the bus */
-  result = gst_atomic_queue_length (bus->priv->queue) != 0;
+  g_mutex_lock (&bus->priv->queue_lock);
+  result = gst_vec_deque_get_length (bus->priv->queue) != 0;
+  g_mutex_unlock (&bus->priv->queue_lock);
 
   return result;
 }
@@ -471,11 +487,9 @@ gst_bus_have_pending (GstBus * bus)
  * @bus: a #GstBus
  * @flushing: whether or not to flush the bus
  *
- * If @flushing, flush out and unref any messages queued in the bus. Releases
+ * If @flushing, flushes out and unrefs any messages queued in the bus. Releases
  * references to the message origin objects. Will flush future messages until
  * gst_bus_set_flushing() sets @flushing to %FALSE.
- *
- * MT safe.
  */
 void
 gst_bus_set_flushing (GstBus * bus, gboolean flushing)
@@ -507,10 +521,10 @@ gst_bus_set_flushing (GstBus * bus, gboolean flushing)
 /**
  * gst_bus_timed_pop_filtered:
  * @bus: a #GstBus to pop from
- * @timeout: a timeout in nanoseconds, or GST_CLOCK_TIME_NONE to wait forever
- * @types: message types to take into account, GST_MESSAGE_ANY for any type
+ * @timeout: a timeout in nanoseconds, or %GST_CLOCK_TIME_NONE to wait forever
+ * @types: message types to take into account, %GST_MESSAGE_ANY for any type
  *
- * Get a message from the bus whose type matches the message type mask @types,
+ * Gets a message from the bus whose type matches the message type mask @types,
  * waiting up to the specified timeout (and discarding any messages that do not
  * match the mask provided).
  *
@@ -520,18 +534,14 @@ gst_bus_set_flushing (GstBus * bus, gboolean flushing)
  *
  * Returns: (transfer full) (nullable): a #GstMessage matching the
  *     filter in @types, or %NULL if no matching message was found on
- *     the bus until the timeout expired. The message is taken from
- *     the bus and needs to be unreffed with gst_message_unref() after
- *     usage.
- *
- * MT safe.
+ *     the bus until the timeout expired.
  */
 GstMessage *
 gst_bus_timed_pop_filtered (GstBus * bus, GstClockTime timeout,
     GstMessageType types)
 {
   GstMessage *message;
-  GTimeVal now, then;
+  gint64 now, then;
   gboolean first_round = TRUE;
   GstClockTime elapsed = 0;
 
@@ -544,10 +554,10 @@ gst_bus_timed_pop_filtered (GstBus * bus, GstClockTime timeout,
   while (TRUE) {
     gint ret;
 
-    GST_LOG_OBJECT (bus, "have %d messages",
-        gst_atomic_queue_length (bus->priv->queue));
+    GST_LOG_OBJECT (bus, "have %" G_GSIZE_FORMAT " messages",
+        gst_vec_deque_get_length (bus->priv->queue));
 
-    while ((message = gst_atomic_queue_pop (bus->priv->queue))) {
+    while ((message = gst_vec_deque_pop_head (bus->priv->queue))) {
       if (bus->priv->poll) {
         while (!gst_poll_read_control (bus->priv->poll)) {
           if (errno == EWOULDBLOCK) {
@@ -591,12 +601,12 @@ gst_bus_timed_pop_filtered (GstBus * bus, GstClockTime timeout,
 
     else if (timeout != GST_CLOCK_TIME_NONE) {
       if (first_round) {
-        g_get_current_time (&then);
+        then = g_get_monotonic_time ();
         first_round = FALSE;
       } else {
-        g_get_current_time (&now);
+        now = g_get_monotonic_time ();
 
-        elapsed = GST_TIMEVAL_TO_TIME (now) - GST_TIMEVAL_TO_TIME (then);
+        elapsed = (now - then) * GST_USECOND;
 
         if (elapsed > timeout)
           break;
@@ -610,10 +620,10 @@ gst_bus_timed_pop_filtered (GstBus * bus, GstClockTime timeout,
     g_mutex_lock (&bus->priv->queue_lock);
 
     if (ret == 0) {
-      GST_INFO_OBJECT (bus, "timed out, breaking loop");
+      GST_DEBUG_OBJECT (bus, "timed out, breaking loop");
       break;
     } else {
-      GST_INFO_OBJECT (bus, "we got woken up, recheck for message");
+      GST_DEBUG_OBJECT (bus, "we got woken up, recheck for message");
     }
   }
 
@@ -630,7 +640,7 @@ beach:
  * @bus: a #GstBus to pop
  * @timeout: a timeout
  *
- * Get a message from the bus, waiting up to the specified timeout.
+ * Gets a message from the bus, waiting up to the specified timeout.
  *
  * If @timeout is 0, this function behaves like gst_bus_pop(). If @timeout is
  * #GST_CLOCK_TIME_NONE, this function will block forever until a message was
@@ -638,10 +648,7 @@ beach:
  *
  * Returns: (transfer full) (nullable): the #GstMessage that is on the
  *     bus after the specified timeout or %NULL if the bus is empty
- *     after the timeout expired.  The message is taken from the bus
- *     and needs to be unreffed with gst_message_unref() after usage.
- *
- * MT safe.
+ *     after the timeout expired.
  */
 GstMessage *
 gst_bus_timed_pop (GstBus * bus, GstClockTime timeout)
@@ -656,7 +663,7 @@ gst_bus_timed_pop (GstBus * bus, GstClockTime timeout)
  * @bus: a #GstBus to pop
  * @types: message types to take into account
  *
- * Get a message matching @type from the bus.  Will discard all messages on
+ * Gets a message matching @type from the bus.  Will discard all messages on
  * the bus that do not match @type and that have been posted before the first
  * message that does match @type.  If there is no message matching @type on
  * the bus, all messages will be discarded. It is not possible to use message
@@ -664,10 +671,7 @@ gst_bus_timed_pop (GstBus * bus, GstClockTime timeout)
  *
  * Returns: (transfer full) (nullable): the next #GstMessage matching
  *     @type that is on the bus, or %NULL if the bus is empty or there
- *     is no message matching @type. The message is taken from the bus
- *     and needs to be unreffed with gst_message_unref() after usage.
- *
- * MT safe.
+ *     is no message matching @type.
  */
 GstMessage *
 gst_bus_pop_filtered (GstBus * bus, GstMessageType types)
@@ -682,14 +686,10 @@ gst_bus_pop_filtered (GstBus * bus, GstMessageType types)
  * gst_bus_pop:
  * @bus: a #GstBus to pop
  *
- * Get a message from the bus.
+ * Gets a message from the bus.
  *
  * Returns: (transfer full) (nullable): the #GstMessage that is on the
- *     bus, or %NULL if the bus is empty. The message is taken from
- *     the bus and needs to be unreffed with gst_message_unref() after
- *     usage.
- *
- * MT safe.
+ *     bus, or %NULL if the bus is empty.
  */
 GstMessage *
 gst_bus_pop (GstBus * bus)
@@ -703,14 +703,11 @@ gst_bus_pop (GstBus * bus)
  * gst_bus_peek:
  * @bus: a #GstBus
  *
- * Peek the message on the top of the bus' queue. The message will remain
- * on the bus' message queue. A reference is returned, and needs to be unreffed
- * by the caller.
+ * Peeks the message on the top of the bus' queue. The message will remain
+ * on the bus' message queue.
  *
  * Returns: (transfer full) (nullable): the #GstMessage that is on the
  *     bus, or %NULL if the bus is empty.
- *
- * MT safe.
  */
 GstMessage *
 gst_bus_peek (GstBus * bus)
@@ -720,7 +717,7 @@ gst_bus_peek (GstBus * bus)
   g_return_val_if_fail (GST_IS_BUS (bus), NULL);
 
   g_mutex_lock (&bus->priv->queue_lock);
-  message = gst_atomic_queue_peek (bus->priv->queue);
+  message = gst_vec_deque_peek_head (bus->priv->queue);
   if (message)
     gst_message_ref (message);
   g_mutex_unlock (&bus->priv->queue_lock);
@@ -804,13 +801,6 @@ typedef struct
   GstBus *bus;
 } GstBusSource;
 
-static gboolean
-gst_bus_source_prepare (GSource * source, gint * timeout)
-{
-  *timeout = -1;
-  return FALSE;
-}
-
 static gboolean
 gst_bus_source_check (GSource * source)
 {
@@ -865,53 +855,54 @@ no_handler:
 }
 
 static void
-gst_bus_source_finalize (GSource * source)
+gst_bus_source_dispose (GSource * source)
 {
   GstBusSource *bsource = (GstBusSource *) source;
   GstBus *bus;
 
   bus = bsource->bus;
 
-  GST_DEBUG_OBJECT (bus, "finalize source %p", source);
+  GST_DEBUG_OBJECT (bus, "disposing source %p", source);
 
   GST_OBJECT_LOCK (bus);
-  if (bus->priv->signal_watch == source)
-    bus->priv->signal_watch = NULL;
+  if (bus->priv->gsource == source)
+    bus->priv->gsource = NULL;
   GST_OBJECT_UNLOCK (bus);
+}
 
-  gst_object_unref (bsource->bus);
-  bsource->bus = NULL;
+static void
+gst_bus_source_finalize (GSource * source)
+{
+  GstBusSource *bsource = (GstBusSource *) source;
+
+  gst_clear_object (&bsource->bus);
 }
 
 static GSourceFuncs gst_bus_source_funcs = {
-  gst_bus_source_prepare,
+  NULL,
   gst_bus_source_check,
   gst_bus_source_dispatch,
   gst_bus_source_finalize
 };
 
-/**
- * gst_bus_create_watch:
- * @bus: a #GstBus to create the watch for
- *
- * Create watch for this bus. The GSource will be dispatched whenever
- * a message is on the bus. After the GSource is dispatched, the
- * message is popped off the bus and unreffed.
- *
- * Returns: (transfer full) (nullable): a #GSource that can be added to a mainloop.
- */
-GSource *
-gst_bus_create_watch (GstBus * bus)
+
+static GSource *
+gst_bus_create_watch_unlocked (GstBus * bus)
 {
   GstBusSource *source;
 
-  g_return_val_if_fail (GST_IS_BUS (bus), NULL);
-  g_return_val_if_fail (bus->priv->poll != NULL, NULL);
+  if (bus->priv->gsource) {
+    GST_ERROR_OBJECT (bus,
+        "Tried to add new GSource while one was already there");
+    return NULL;
+  }
 
-  source = (GstBusSource *) g_source_new (&gst_bus_source_funcs,
+  bus->priv->gsource = g_source_new (&gst_bus_source_funcs,
       sizeof (GstBusSource));
+  source = (GstBusSource *) bus->priv->gsource;
 
   g_source_set_name ((GSource *) source, "GStreamer message bus watch");
+  g_source_set_dispose_function ((GSource *) source, gst_bus_source_dispose);
 
   source->bus = gst_object_ref (bus);
   g_source_add_poll ((GSource *) source, &bus->priv->pollfd);
@@ -919,6 +910,34 @@ gst_bus_create_watch (GstBus * bus)
   return (GSource *) source;
 }
 
+/**
+ * gst_bus_create_watch:
+ * @bus: a #GstBus to create the watch for
+ *
+ * Create watch for this bus. The #GSource will be dispatched whenever
+ * a message is on the bus. After the GSource is dispatched, the
+ * message is popped off the bus and unreffed.
+ *
+ * As with other watches, there can only be one watch on the bus, including
+ * any signal watch added with #gst_bus_add_signal_watch.
+ *
+ * Returns: (transfer full) (nullable): a #GSource that can be added to a #GMainLoop.
+ */
+GSource *
+gst_bus_create_watch (GstBus * bus)
+{
+  GSource *source;
+
+  g_return_val_if_fail (GST_IS_BUS (bus), NULL);
+  g_return_val_if_fail (bus->priv->poll != NULL, NULL);
+
+  GST_OBJECT_LOCK (bus);
+  source = gst_bus_create_watch_unlocked (bus);
+  GST_OBJECT_UNLOCK (bus);
+
+  return source;
+}
+
 /* must be called with the bus OBJECT LOCK */
 static guint
 gst_bus_add_watch_full_unlocked (GstBus * bus, gint priority,
@@ -928,13 +947,13 @@ gst_bus_add_watch_full_unlocked (GstBus * bus, gint priority,
   guint id;
   GSource *source;
 
-  if (bus->priv->signal_watch) {
+  if (bus->priv->gsource) {
     GST_ERROR_OBJECT (bus,
         "Tried to add new watch while one was already there");
     return 0;
   }
 
-  source = gst_bus_create_watch (bus);
+  source = gst_bus_create_watch_unlocked (bus);
   if (!source) {
     g_critical ("Creating bus watch failed");
     return 0;
@@ -950,7 +969,7 @@ gst_bus_add_watch_full_unlocked (GstBus * bus, gint priority,
   g_source_unref (source);
 
   if (id) {
-    bus->priv->signal_watch = source;
+    bus->priv->gsource = source;
   }
 
   GST_DEBUG_OBJECT (bus, "New source %p with id %u", source, id);
@@ -975,7 +994,7 @@ gst_bus_add_watch_full_unlocked (GstBus * bus, gint priority,
  * There can only be a single bus watch per bus, you must remove it before you
  * can set a new one.
  *
- * The bus watch will only work if a GLib main loop is being run.
+ * The bus watch will only work if a #GMainLoop is being run.
  *
  * When @func is called, the message belongs to the caller; if you want to
  * keep a copy of it, call gst_message_ref() before leaving @func.
@@ -987,8 +1006,6 @@ gst_bus_add_watch_full_unlocked (GstBus * bus, gint priority,
  * The bus watch will take its own reference to the @bus, so it is safe to unref
  * @bus using gst_object_unref() after setting the bus watch.
  *
- * MT safe.
- *
  * Returns: The event source id or 0 if @bus already got an event source.
  */
 guint
@@ -1013,7 +1030,7 @@ gst_bus_add_watch_full (GstBus * bus, gint priority,
  * @user_data: user data passed to @func.
  *
  * Adds a bus watch to the default main context with the default priority
- * (%G_PRIORITY_DEFAULT). It is also possible to use a non-default main
+ * ( %G_PRIORITY_DEFAULT ). It is also possible to use a non-default main
  * context set up using g_main_context_push_thread_default() (before
  * one had to create a bus watch source and attach it to the desired main
  * context 'manually').
@@ -1022,7 +1039,7 @@ gst_bus_add_watch_full (GstBus * bus, gint priority,
  * There can only be a single bus watch per bus, you must remove it before you
  * can set a new one.
  *
- * The bus watch will only work if a GLib main loop is being run.
+ * The bus watch will only work if a #GMainLoop is being run.
  *
  * The watch can be removed using gst_bus_remove_watch() or by returning %FALSE
  * from @func. If the watch was added to the default main context it is also
@@ -1031,8 +1048,6 @@ gst_bus_add_watch_full (GstBus * bus, gint priority,
  * The bus watch will take its own reference to the @bus, so it is safe to unref
  * @bus using gst_object_unref() after setting the bus watch.
  *
- * MT safe.
- *
  * Returns: The event source id or 0 if @bus already got an event source.
  */
 guint
@@ -1062,7 +1077,7 @@ gst_bus_remove_watch (GstBus * bus)
 
   GST_OBJECT_LOCK (bus);
 
-  if (bus->priv->signal_watch == NULL) {
+  if (bus->priv->gsource == NULL) {
     GST_ERROR_OBJECT (bus, "no bus watch was present");
     goto error;
   }
@@ -1073,8 +1088,8 @@ gst_bus_remove_watch (GstBus * bus)
     goto error;
   }
 
-  source =
-      bus->priv->signal_watch ? g_source_ref (bus->priv->signal_watch) : NULL;
+  source = g_source_ref (bus->priv->gsource);
+  bus->priv->gsource = NULL;
 
   GST_OBJECT_UNLOCK (bus);
 
@@ -1140,7 +1155,7 @@ poll_destroy (GstBusPollData * poll_data, gpointer unused)
   poll_data->source_running = FALSE;
   if (!poll_data->timeout_id) {
     g_main_loop_unref (poll_data->loop);
-    g_slice_free (GstBusPollData, poll_data);
+    g_free (poll_data);
   }
 }
 
@@ -1150,7 +1165,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
   poll_data->timeout_id = 0;
   if (!poll_data->source_running) {
     g_main_loop_unref (poll_data->loop);
-    g_slice_free (GstBusPollData, poll_data);
+    g_free (poll_data);
   }
 }
 
@@ -1162,7 +1177,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
  * @timeout: the poll timeout, as a #GstClockTime, or #GST_CLOCK_TIME_NONE to poll
  * indefinitely.
  *
- * Poll the bus for messages. Will block while waiting for messages to come.
+ * Polls the bus for messages. Will block while waiting for messages to come.
  * You can specify a maximum time to poll with the @timeout parameter. If
  * @timeout is negative, this function will block indefinitely.
  *
@@ -1176,7 +1191,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
  * signal handler will see the same messages that this function sees -- neither
  * will steal messages from the other.
  *
- * This function will run a main loop from the default main context when
+ * This function will run a #GMainLoop from the default main context when
  * polling.
  *
  * You should never use this function, since it is pure evil. This is
@@ -1197,9 +1212,7 @@ poll_destroy_timeout (GstBusPollData * poll_data)
  * from there.
  *
  * Returns: (transfer full) (nullable): the message that was received,
- *     or %NULL if the poll timed out. The message is taken from the
- *     bus and needs to be unreffed with gst_message_unref() after
- *     usage.
+ *     or %NULL if the poll timed out.
  */
 GstMessage *
 gst_bus_poll (GstBus * bus, GstMessageType events, GstClockTime timeout)
@@ -1210,7 +1223,7 @@ gst_bus_poll (GstBus * bus, GstMessageType events, GstClockTime timeout)
 
   g_return_val_if_fail (GST_IS_BUS (bus), NULL);
 
-  poll_data = g_slice_new (GstBusPollData);
+  poll_data = g_new (GstBusPollData, 1);
   poll_data->source_running = TRUE;
   poll_data->loop = g_main_loop_new (NULL, FALSE);
   poll_data->events = events;
@@ -1282,10 +1295,10 @@ gst_bus_async_signal_func (GstBus * bus, GstMessage * message, gpointer data)
  * @message: the #GstMessage received
  * @data: user data
  *
- * A helper GstBusSyncHandler that can be used to convert all synchronous
+ * A helper #GstBusSyncHandler that can be used to convert all synchronous
  * messages into signals.
  *
- * Returns: GST_BUS_PASS
+ * Returns: %GST_BUS_PASS
  */
 GstBusSyncReply
 gst_bus_sync_signal_handler (GstBus * bus, GstMessage * message, gpointer data)
@@ -1316,13 +1329,11 @@ gst_bus_sync_signal_handler (GstBus * bus, GstMessage * message, gpointer data)
  * as this function is called.
  *
  * While this function looks similar to gst_bus_add_signal_watch(), it is not
- * exactly the same -- this function enables <emphasis>synchronous</emphasis> emission of
+ * exactly the same -- this function enables *synchronous* emission of
  * signals when messages arrive; gst_bus_add_signal_watch() adds an idle callback
- * to pop messages off the bus <emphasis>asynchronously</emphasis>. The sync-message signal
+ * to pop messages off the bus *asynchronously*. The sync-message signal
  * comes from the thread of whatever object posted the message; the "message"
- * signal is marshalled to the main thread via the main loop.
- *
- * MT safe.
+ * signal is marshalled to the main thread via the #GMainLoop.
  */
 void
 gst_bus_enable_sync_message_emission (GstBus * bus)
@@ -1348,8 +1359,6 @@ gst_bus_enable_sync_message_emission (GstBus * bus)
  * "cancelled" by calling this function. In this way the semantics are exactly
  * the same as gst_object_ref() that which calls enable should also call
  * disable.
- *
- * MT safe.
  */
 void
 gst_bus_disable_sync_message_emission (GstBus * bus)
@@ -1374,7 +1383,7 @@ gst_bus_disable_sync_message_emission (GstBus * bus)
  * main context 'manually').
  *
  * After calling this statement, the bus will emit the "message" signal for each
- * message posted on the bus when the main loop is running.
+ * message posted on the bus when the #GMainLoop is running.
  *
  * This function may be called multiple times. To clean up, the caller is
  * responsible for calling gst_bus_remove_signal_watch() as many times as this
@@ -1382,8 +1391,6 @@ gst_bus_disable_sync_message_emission (GstBus * bus)
  *
  * There can only be a single bus watch per bus, you must remove any signal
  * watch before you can set another type of watch.
- *
- * MT safe.
  */
 void
 gst_bus_add_signal_watch_full (GstBus * bus, gint priority)
@@ -1396,13 +1403,13 @@ gst_bus_add_signal_watch_full (GstBus * bus, gint priority)
   if (bus->priv->num_signal_watchers > 0)
     goto done;
 
-  /* this should not fail because the counter above takes care of it */
-  g_assert (!bus->priv->signal_watch);
+  if (bus->priv->gsource)
+    goto has_gsource;
 
   gst_bus_add_watch_full_unlocked (bus, priority, gst_bus_async_signal_func,
       NULL, NULL);
 
-  if (G_UNLIKELY (!bus->priv->signal_watch))
+  if (G_UNLIKELY (!bus->priv->gsource))
     goto add_failed;
 
 done:
@@ -1419,6 +1426,12 @@ add_failed:
     GST_OBJECT_UNLOCK (bus);
     return;
   }
+has_gsource:
+  {
+    g_critical ("Bus %s already has a GSource watch", GST_OBJECT_NAME (bus));
+    GST_OBJECT_UNLOCK (bus);
+    return;
+  }
 }
 
 /**
@@ -1426,7 +1439,7 @@ add_failed:
  * @bus: a #GstBus on which you want to receive the "message" signal
  *
  * Adds a bus signal watch to the default main context with the default priority
- * (%G_PRIORITY_DEFAULT). It is also possible to use a non-default
+ * ( %G_PRIORITY_DEFAULT ). It is also possible to use a non-default
  * main context set up using g_main_context_push_thread_default() (before
  * one had to create a bus watch source and attach it to the desired main
  * context 'manually').
@@ -1437,8 +1450,6 @@ add_failed:
  * This function may be called multiple times. To clean up, the caller is
  * responsible for calling gst_bus_remove_signal_watch() as many times as this
  * function is called.
- *
- * MT safe.
  */
 void
 gst_bus_add_signal_watch (GstBus * bus)
@@ -1451,8 +1462,6 @@ gst_bus_add_signal_watch (GstBus * bus)
  * @bus: a #GstBus you previously added a signal watch to
  *
  * Removes a signal watch previously added with gst_bus_add_signal_watch().
- *
- * MT safe.
  */
 void
 gst_bus_remove_signal_watch (GstBus * bus)
@@ -1472,11 +1481,12 @@ gst_bus_remove_signal_watch (GstBus * bus)
   if (bus->priv->num_signal_watchers > 0)
     goto done;
 
-  GST_DEBUG_OBJECT (bus, "removing signal watch %u",
-      g_source_get_id (bus->priv->signal_watch));
+  GST_DEBUG_OBJECT (bus, "removing gsource %u",
+      g_source_get_id (bus->priv->gsource));
 
-  source =
-      bus->priv->signal_watch ? g_source_ref (bus->priv->signal_watch) : NULL;
+  g_assert (bus->priv->gsource);
+  source = g_source_ref (bus->priv->gsource);
+  bus->priv->gsource = NULL;
 
 done:
   GST_OBJECT_UNLOCK (bus);
