@@ -104,13 +104,14 @@ GST_DEBUG_CATEGORY_STATIC (devicemonitor_debug);
 struct _GstDeviceMonitorPrivate
 {
   gboolean started;
+  GThread *start_thread;
 
   GstBus *bus;
 
   GPtrArray *providers;
   GPtrArray *filters;
 
-  GList *started_providers;
+  GSList *started_providers;
 
   guint last_id;
   GList *hidden;
@@ -277,9 +278,9 @@ bus_sync_message (GstBus * bus, GstMessage * message,
       gst_message_parse_device_changed (message, &device, NULL);
 
     GST_OBJECT_LOCK (monitor);
-    provider =
-        GST_DEVICE_PROVIDER (gst_object_get_parent (GST_OBJECT (device)));
-    if (is_provider_hidden (monitor, monitor->priv->hidden, provider)) {
+    provider = GST_DEVICE_PROVIDER (GST_MESSAGE_SRC (message));
+    if (provider &&
+        is_provider_hidden (monitor, monitor->priv->hidden, provider)) {
       matches = FALSE;
     } else {
       guint i;
@@ -299,7 +300,6 @@ bus_sync_message (GstBus * bus, GstMessage * message,
     }
     GST_OBJECT_UNLOCK (monitor);
 
-    gst_object_unref (provider);
     gst_object_unref (device);
 
     if (matches)
@@ -325,6 +325,9 @@ gst_device_monitor_init (GstDeviceMonitor * self)
   self->priv->providers = g_ptr_array_new ();
   self->priv->filters = g_ptr_array_new_with_free_func (
       (GDestroyNotify) device_filter_free);
+  self->priv->started_providers = NULL;
+  self->priv->started = FALSE;
+  self->priv->start_thread = NULL;
 
   self->priv->last_id = 1;
 }
@@ -353,7 +356,21 @@ gst_device_monitor_dispose (GObject * object)
 {
   GstDeviceMonitor *self = GST_DEVICE_MONITOR (object);
 
-  g_return_if_fail (!self->priv->started);
+  if (self->priv->started) {
+    g_critical ("gst_device_monitor_dispose: disposed without stopping, "
+        "started providers were leaked");
+  }
+
+  /*
+   * We ensure that dispose is never called while we still hold a reference to
+   * the GThread running monitor_thread_func() by having the func hold
+   * a reference to the monitor. The func will release the monitor's reference
+   * to the GThread before releasing its own reference to the monitor.
+   *
+   * When stopping, _stop() will steal the monitor's reference to the GThread
+   * and join it, achieving the same result.
+   */
+  g_warn_if_fail (!self->priv->start_thread);
 
   if (self->priv->providers) {
     while (self->priv->providers->len)
@@ -473,14 +490,101 @@ gst_device_monitor_get_devices (GstDeviceMonitor * monitor)
   return devices.head;
 }
 
+static gpointer
+monitor_thread_func (gpointer data)
+{
+  GSList *started = NULL;
+  GQueue pending = G_QUEUE_INIT;
+  GstDeviceMonitor *monitor = data;
+  GstDeviceProvider *provider;
+
+  GST_OBJECT_LOCK (monitor);
+
+  if (!monitor->priv->started) {
+    GST_OBJECT_UNLOCK (monitor);
+    goto done;
+  }
+
+  for (int i = 0; i < monitor->priv->providers->len; i++) {
+    provider = g_ptr_array_index (monitor->priv->providers, i);
+    g_queue_push_tail (&pending, gst_object_ref (provider));
+  }
+
+  while ((provider = g_queue_pop_head (&pending))) {
+    GST_OBJECT_UNLOCK (monitor);
+
+    if (gst_device_provider_start (provider)) {
+      started = g_slist_prepend (started, provider);
+    } else {
+      gst_clear_object (&provider);
+    }
+
+    GST_OBJECT_LOCK (monitor);
+
+    /* We were stopped while unlocked in this iteration. Stop the provider
+     * we just started, dispose all pending providers, and return without
+     * modifying any priv members */
+    if (!monitor->priv->started) {
+      /* Assert that the monitor lost its reference to this GThread when it
+       * was stopped */
+      g_assert (monitor->priv->start_thread == NULL);
+      GST_OBJECT_UNLOCK (monitor);
+
+      if (provider) {
+        gst_device_provider_stop (provider);
+        gst_clear_object (&provider);
+      }
+
+      g_queue_clear_full (&pending, gst_object_unref);
+
+      /* Free the list we prepended above by detaching it from the rest of the
+       * list, which is monitor->priv->started_providers. This is safe because
+       * this is a singly-linked list. */
+      started->next = NULL;
+      g_slist_free (started);
+      started = NULL;
+
+      goto done;
+    }
+
+    if (started) {
+      monitor->priv->started_providers = started;
+    }
+  }
+
+  if (monitor->priv->started_providers == NULL) {
+    monitor->priv->started = FALSE;
+  }
+
+  g_clear_pointer (&monitor->priv->start_thread, g_thread_unref);
+  GST_OBJECT_UNLOCK (monitor);
+
+done:
+  gst_bus_post (monitor->priv->bus,
+      gst_message_new_device_monitor_started (GST_OBJECT (monitor),
+          started != NULL));
+  gst_object_unref (monitor);
+
+  return NULL;
+}
+
 /**
  * gst_device_monitor_start:
  * @monitor: A #GstDeviceMonitor
  *
- * Starts monitoring the devices, one this has succeeded, the
+ * Starts monitoring the devices, once this has succeeded, the
  * %GST_MESSAGE_DEVICE_ADDED and %GST_MESSAGE_DEVICE_REMOVED messages
  * will be emitted on the bus when the list of devices changes.
  *
+ * Since 1.28, device providers are started asynchronously and
+ * %GST_MESSAGE_DEVICE_MONITOR_STARTED will be emitted once the initial list
+ * of devices has been populated, signalling that monitor startup has
+ * completed.
+ *
+ * The monitor will hold a strong reference to itself while it is populating
+ * devices asynchronously, so you must call gst_device_monitor_stop() before
+ * unreffing if you want monitoring to stop immediately.
+ *
  * Returns: %TRUE if the device monitoring could be started, i.e. at least a
  *     single device provider was started successfully.
  *
@@ -490,10 +594,7 @@ gst_device_monitor_get_devices (GstDeviceMonitor * monitor)
 gboolean
 gst_device_monitor_start (GstDeviceMonitor * monitor)
 {
-  guint i;
-  GQueue pending = G_QUEUE_INIT;
-  GList *started = NULL;
-  GstDeviceProvider *provider;
+  gboolean ret;
 
   g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), FALSE);
 
@@ -504,6 +605,10 @@ gst_device_monitor_start (GstDeviceMonitor * monitor)
     GST_DEBUG_OBJECT (monitor, "Monitor started already");
     return TRUE;
   }
+
+  /* This is cleared alongside priv->started being set to FALSE */
+  g_assert (monitor->priv->started_providers == NULL);
+
   if (monitor->priv->filters->len == 0) {
     GST_WARNING_OBJECT (monitor, "No filters have been set, will expose all "
         "devices found");
@@ -516,39 +621,20 @@ gst_device_monitor_start (GstDeviceMonitor * monitor)
     return FALSE;
   }
 
-  monitor->priv->started = TRUE;
+  monitor->priv->start_thread = g_thread_try_new ("gst_device_monitor_start",
+      monitor_thread_func, monitor, NULL);
 
-  gst_bus_set_flushing (monitor->priv->bus, FALSE);
+  if ((ret = monitor->priv->start_thread != NULL)) {
+    // Yield a reference to the GThreadFunc
+    gst_object_ref (monitor);
 
-  for (i = 0; i < monitor->priv->providers->len; i++) {
-    GstDeviceProvider *provider;
-
-    provider = g_ptr_array_index (monitor->priv->providers, i);
-    g_queue_push_tail (&pending, gst_object_ref (provider));
-  }
-
-  while ((provider = g_queue_pop_head (&pending))) {
-    GST_OBJECT_UNLOCK (monitor);
-
-    if (gst_device_provider_start (provider)) {
-      started = g_list_prepend (started, provider);
-    } else {
-      gst_object_unref (provider);
-    }
-
-    GST_OBJECT_LOCK (monitor);
-  }
-
-  if (started) {
-    monitor->priv->started_providers = started;
-  } else {
-    gst_bus_set_flushing (monitor->priv->bus, TRUE);
-    monitor->priv->started = FALSE;
+    monitor->priv->started = TRUE;
+    gst_bus_set_flushing (monitor->priv->bus, FALSE);
   }
 
   GST_OBJECT_UNLOCK (monitor);
 
-  return started != NULL;
+  return ret;
 }
 
 /**
@@ -562,7 +648,8 @@ gst_device_monitor_start (GstDeviceMonitor * monitor)
 void
 gst_device_monitor_stop (GstDeviceMonitor * monitor)
 {
-  GList *started = NULL;
+  GSList *started = NULL;
+  GThread *thread = NULL;
 
   g_return_if_fail (GST_IS_DEVICE_MONITOR (monitor));
 
@@ -577,15 +664,24 @@ gst_device_monitor_stop (GstDeviceMonitor * monitor)
 
   started = monitor->priv->started_providers;
   monitor->priv->started_providers = NULL;
+  /* This will cancel monitor_thread_func() if it is running */
   monitor->priv->started = FALSE;
+  /* Steal GThread reference from the monitor */
+  thread = monitor->priv->start_thread;
+  monitor->priv->start_thread = NULL;
   GST_OBJECT_UNLOCK (monitor);
 
+  if (thread != NULL) {
+    /* Thread has been cancelled above, so this join should return quickly */
+    g_thread_join (thread);
+  }
+
   while (started) {
     GstDeviceProvider *provider = started->data;
 
     gst_device_provider_stop (provider);
 
-    started = g_list_delete_link (started, started);
+    started = g_slist_delete_link (started, started);
     gst_object_unref (provider);
   }
 }
