@@ -19,13 +19,96 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
-
 #ifndef __GST_DEVICE_PROVIDER_H__
 #define __GST_DEVICE_PROVIDER_H__
 
 #include <gst/gstelement.h>
 
+/**
+ * GST_DEVICE_PROVIDER_REGISTER_DEFINE_CUSTOM:
+ * @d_p: The device provider name in lower case, with words separated by '_'.
+ * Used to generate `gst_device_provider_register_*(GstPlugin* plugin)`.
+ * @register_func: pointer to a method with the format: `gboolean register_func (GstPlugin* plugin);`
+ *
+ * A convenience macro to define the entry point of a
+ * device provider `gst_device_provider_register_*(GstPlugin* plugin)` which uses
+ * register_func as the main registration method for the device provider.
+ * As an example, you may define the device provider named "device-provider"
+ * with the namespace `my` as following using `device_provider_register_custom`:
+ *
+ * ```
+ *
+ * gboolean my_device_provider_register_custom (GstPlugin * plugin)
+ * {
+ *    gboolean ret = FALSE;
+ *    ret |= gst_device_provider_register (plugin, "my-device-provider",
+         GST_RANK_PRIMARY, GST_TYPE_MY_DEVICE_PROVIDER);
+ *    return TRUE;
+ * }
+ *
+ * GST_DEVICE_PROVIDER_REGISTER_DEFINE_CUSTOM (my_device_provider, my_device_provider_register_custom)
+ * ```
+ *
+ * Since: 1.20
+ */
+#define GST_DEVICE_PROVIDER_REGISTER_DEFINE_CUSTOM(d_p, register_func) \
+G_BEGIN_DECLS \
+gboolean G_PASTE (gst_device_provider_register_, d_p) (GstPlugin * plugin) \
+{ \
+  return register_func (plugin); \
+} \
+G_END_DECLS
+
+/**
+ * GST_DEVICE_PROVIDER_REGISTER_DEFINE:
+ * @d_p: The device provider name in lower case, with words separated by '_'.
+ * Used to generate `gst_device_provider_register_*(GstPlugin* plugin)`.
+ * @d_p_n: The public name of the device provider
+ * @r: The #GstRank of the device provider (higher rank means more importance when autoplugging, see #GstRank)
+ * @t: The #GType of the device provider.
+ *
+ * A convenience macro to define the entry point of a
+ * device provider `gst_device_provider_register_*(GstPlugin* plugin)`.
+ *
+ * Since: 1.20
+ */
+#define GST_DEVICE_PROVIDER_REGISTER_DEFINE(d_p, d_p_n, r, t) \
+G_BEGIN_DECLS \
+gboolean G_PASTE (gst_device_provider_register_, d_p) (GstPlugin * plugin) \
+{ \
+  return gst_device_provider_register (plugin, d_p_n, r, t); \
+} \
+G_END_DECLS
+
+/**
+ * GST_DEVICE_PROVIDER_REGISTER_DECLARE:
+ * @d_p: The device provider name in lower case, with words separated by '_'.
+ *
+ * This macro can be used to declare a new device provider.
+ * It has to be used in combination with #GST_DEVICE_PROVIDER_REGISTER_DEFINE macro
+ * and must be placed outside any block to declare the device provider registration
+ * function.
+ *
+ * Since: 1.20
+ */
+#define GST_DEVICE_PROVIDER_REGISTER_DECLARE(d_p) \
+G_BEGIN_DECLS \
+gboolean G_PASTE(gst_device_provider_register_, d_p) (GstPlugin * plugin); \
+G_END_DECLS
+
+/**
+ * GST_DEVICE_PROVIDER_REGISTER:
+ * @d_p: The device provider name in lower case, with words separated by '_'.
+ * @plugin: The #GstPlugin where to register the device provider.
+ *
+ * This macro can be used to register a device provider into a #GstPlugin.
+ * This method will be usually called in the plugin init function
+ * but can also be called with a NULL plugin.
+ *
+ * Since: 1.20
+ */
+#define GST_DEVICE_PROVIDER_REGISTER(d_p, plugin) G_PASTE(gst_device_provider_register_, d_p) (plugin)
+
 G_BEGIN_DECLS
 
 typedef struct _GstDeviceProvider GstDeviceProvider;
@@ -71,7 +154,8 @@ struct _GstDeviceProvider {
  * @factory: a pointer to the #GstDeviceProviderFactory that creates this
  *  provider
  * @probe: Returns a list of devices that are currently available.
- *  This should never block.
+ *  This should never block. The devices should not have a parent and should
+ *  be floating.
  * @start: Starts monitoring for new devices. Only subclasses that can know
  *  that devices have been added or remove need to implement this method.
  * @stop: Stops monitoring for new devices. Only subclasses that implement
@@ -104,7 +188,7 @@ GType       gst_device_provider_get_type (void);
 
 
 GST_API
-GList *     gst_device_provider_get_devices    (GstDeviceProvider * provider);
+GList *     gst_device_provider_get_devices    (GstDeviceProvider * provider) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 gboolean    gst_device_provider_start          (GstDeviceProvider * provider);
@@ -116,7 +200,7 @@ GST_API
 gboolean    gst_device_provider_can_monitor    (GstDeviceProvider * provider);
 
 GST_API
-GstBus *    gst_device_provider_get_bus        (GstDeviceProvider * provider);
+GstBus *    gst_device_provider_get_bus        (GstDeviceProvider * provider) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 void        gst_device_provider_device_add     (GstDeviceProvider * provider,
@@ -125,7 +209,7 @@ GST_API
 void        gst_device_provider_device_remove  (GstDeviceProvider * provider,
                                                 GstDevice * device);
 GST_API
-gchar **    gst_device_provider_get_hidden_providers (GstDeviceProvider * provider);
+gchar **    gst_device_provider_get_hidden_providers (GstDeviceProvider * provider) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 void        gst_device_provider_hide_provider        (GstDeviceProvider * provider,
@@ -138,6 +222,9 @@ GST_API
 const gchar * gst_device_provider_get_metadata       (GstDeviceProvider * provider,
                                                       const gchar * key);
 
+GST_API
+gboolean    gst_device_provider_is_started     (GstDeviceProvider * provider);
+
 /* device provider class meta data */
 
 GST_API
@@ -172,9 +259,7 @@ void gst_device_provider_device_changed                    (GstDeviceProvider *
 GST_API
 GstDeviceProviderFactory * gst_device_provider_get_factory (GstDeviceProvider * provider);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstDeviceProvider, gst_object_unref)
-#endif
 
 G_END_DECLS
 
