@@ -73,10 +73,10 @@ GST_API
 const gchar *           gst_device_provider_factory_get_metadata       (GstDeviceProviderFactory *factory, const gchar *key);
 
 GST_API
-gchar **                gst_device_provider_factory_get_metadata_keys  (GstDeviceProviderFactory *factory);
+gchar **                gst_device_provider_factory_get_metadata_keys  (GstDeviceProviderFactory *factory) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstDeviceProvider*       gst_device_provider_factory_get                (GstDeviceProviderFactory *factory) G_GNUC_MALLOC;
+GstDeviceProvider*       gst_device_provider_factory_get                (GstDeviceProviderFactory *factory) G_GNUC_MALLOC G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 GstDeviceProvider*       gst_device_provider_factory_get_by_name        (const gchar *factoryname) G_GNUC_MALLOC;
@@ -95,9 +95,7 @@ GST_API
 GList *       gst_device_provider_factory_list_get_device_providers (
                                                        GstRank minrank) G_GNUC_MALLOC;
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstDeviceProviderFactory, gst_object_unref)
-#endif
 
 G_END_DECLS
 
