@@ -315,6 +315,9 @@ gst_memory_map (GstMemory * mem, GstMapInfo * info, GstMapFlags flags)
 
   info->data = info->data + mem->offset;
 
+  if ((flags & GST_MAP_REF_MEMORY) != 0)
+    gst_memory_ref (info->memory);
+
   return TRUE;
 
   /* ERRORS */
@@ -349,11 +352,65 @@ gst_memory_unmap (GstMemory * mem, GstMapInfo * info)
   g_return_if_fail (info != NULL);
   g_return_if_fail (info->memory == mem);
 
+  gst_map_info_clear (info);
+}
+
+/**
+ * gst_map_info_init:
+ * @info: a #GstMapInfo
+ *
+ * Initializes @info.
+ *
+ * Since: 1.28
+ */
+void
+gst_map_info_init (GstMapInfo * info)
+{
+  g_return_if_fail (info != NULL);
+
+  memset (info, 0, sizeof (*info));
+}
+
+/**
+ * gst_map_info_clear:
+ * @info: a #GstMapInfo
+ *
+ * Release the memory obtained with gst_memory_map()
+ *
+ * Since: 1.28
+ */
+void
+gst_map_info_clear (GstMapInfo * info)
+{
+  GstMemory *mem;
+
+  g_return_if_fail (info != NULL);
+
+  mem = info->memory;
+
+  /* Allow to unmap even if not mapped, to work nicely with
+   * g_auto (GstMapInfo) map = GST_MAP_INFO_INIT;
+   */
+  if (!mem)
+    return;
+
   if (mem->allocator->mem_unmap_full)
     mem->allocator->mem_unmap_full (mem, info);
   else
     mem->allocator->mem_unmap (mem);
   gst_memory_unlock (mem, (GstLockFlags) info->flags);
+
+  if ((info->flags & GST_MAP_REF_MEMORY) != 0)
+    gst_memory_unref (info->memory);
+
+  /* Reset various fields to avoid use-after-frees.
+   * This also makes it possible to call clear() twice.
+   * Keep size/maxsize set because various code is
+   * making use of it and it's less critical. */
+  info->memory = NULL;
+  info->flags = 0;
+  info->data = NULL;
+  memset (&info->user_data, 0, sizeof (info->user_data));
 }
 
 /**
@@ -598,3 +655,23 @@ gst_memory_take (GstMemory ** old_memory, GstMemory * new_memory)
   return gst_mini_object_take ((GstMiniObject **) old_memory,
       (GstMiniObject *) new_memory);
 }
+
+/**
+ * gst_map_info_get_data:
+ * @info: a #GstMapInfo
+ * @size: (out): Return location of the size of the data.
+ *
+ * Returns: (transfer none) (array length=size) (nullable): Data of @info.
+ *
+ * Since: 1.28
+ */
+guint8 *
+gst_map_info_get_data (GstMapInfo * info, gsize * size)
+{
+  g_return_val_if_fail (info != NULL, NULL);
+  g_return_val_if_fail (size != NULL, NULL);
+
+  *size = info->size;
+
+  return info->data;
+}
