@@ -137,8 +137,8 @@ typedef enum {
  * @GST_FLOW_EOS:                Pad is EOS.
  * @GST_FLOW_NOT_NEGOTIATED:	 Pad is not negotiated.
  * @GST_FLOW_ERROR:		 Some (fatal) error occurred. Element generating
- *                               this error should post an error message with more
- *                               details.
+ *                               this error should post an error message using
+ *                               GST_ELEMENT_ERROR() with more details.
  * @GST_FLOW_NOT_SUPPORTED:	 This operation is not supported.
  * @GST_FLOW_CUSTOM_SUCCESS:	 Elements can use values starting from
  *                               this (and higher) to define custom success
@@ -264,7 +264,7 @@ typedef gboolean		(*GstPadActivateModeFunction)	(GstPad *pad, GstObject *parent,
 /**
  * GstPadChainFunction:
  * @pad: the sink #GstPad that performed the chain.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @buffer: (transfer full): the #GstBuffer that is chained, not %NULL.
@@ -287,7 +287,7 @@ typedef GstFlowReturn		(*GstPadChainFunction)		(GstPad *pad, GstObject *parent,
 /**
  * GstPadChainListFunction:
  * @pad: the sink #GstPad that performed the chain.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @list: (transfer full): the #GstBufferList that is chained, not %NULL.
@@ -310,7 +310,7 @@ typedef GstFlowReturn		(*GstPadChainListFunction)	(GstPad *pad, GstObject *paren
 /**
  * GstPadGetRangeFunction:
  * @pad: the src #GstPad to perform the getrange on.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @offset: the offset of the range
@@ -361,7 +361,7 @@ typedef GstFlowReturn		(*GstPadGetRangeFunction)	(GstPad *pad, GstObject *parent
 /**
  * GstPadEventFunction:
  * @pad: the #GstPad to handle the event.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @event: (transfer full): the #GstEvent to handle.
@@ -376,7 +376,7 @@ typedef gboolean		(*GstPadEventFunction)		(GstPad *pad, GstObject *parent,
 /**
  * GstPadEventFullFunction:
  * @pad: the #GstPad to handle the event.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @event: (transfer full): the #GstEvent to handle.
@@ -400,7 +400,7 @@ typedef GstFlowReturn		(*GstPadEventFullFunction)	(GstPad *pad, GstObject *paren
 /**
  * GstPadIterIntLinkFunction:
  * @pad: The #GstPad to query.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  *
@@ -417,7 +417,7 @@ typedef GstIterator*           (*GstPadIterIntLinkFunction)    (GstPad *pad, Gst
 /**
  * GstPadQueryFunction:
  * @pad: the #GstPad to query.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @query: the #GstQuery object to execute
@@ -434,7 +434,7 @@ typedef gboolean		(*GstPadQueryFunction)		(GstPad *pad, GstObject *parent,
 /**
  * GstPadLinkFunction:
  * @pad: the #GstPad that is linked.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  * @peer: the peer #GstPad of the link
@@ -447,11 +447,14 @@ typedef GstPadLinkReturn	(*GstPadLinkFunction)		(GstPad *pad, GstObject *parent,
 /**
  * GstPadUnlinkFunction:
  * @pad: the #GstPad that is linked.
- * @parent: (allow-none): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
+ * @parent: (nullable): the parent of @pad. If the #GST_PAD_FLAG_NEED_PARENT
  *          flag is set, @parent is guaranteed to be not-%NULL and remain valid
  *          during the execution of this function.
  *
  * Function signature to handle a unlinking the pad prom its peer.
+ *
+ * The pad's lock is already held when the unlink function is called, so most
+ * pad functions cannot be called from within the callback.
  */
 typedef void			(*GstPadUnlinkFunction)		(GstPad *pad, GstObject *parent);
 
@@ -545,9 +548,12 @@ typedef enum
  *        the data item is not passed upstream. In both cases, no other probes
  *        are called for this item and %GST_FLOW_OK or %TRUE is returned to the
  *        caller.
- * @GST_PAD_PROBE_REMOVE: remove this probe.
+ * @GST_PAD_PROBE_REMOVE: remove this probe, passing the data. For blocking probes
+ *        this will cause data flow to unblock, unless there are also other
+ *        blocking probes installed.
  * @GST_PAD_PROBE_PASS: pass the data item in the block probe and block on the
- *        next item.
+ *        next item. Note, that if there are multiple pad probes installed and
+ *        any probe returns PASS, the data will be passed.
  * @GST_PAD_PROBE_HANDLED: Data has been handled in the probe and will not be
  *        forwarded further. For events and buffers this is the same behaviour as
  *        %GST_PAD_PROBE_DROP (except that in this case you need to unref the buffer
@@ -573,7 +579,7 @@ typedef enum
  * GstPadProbeInfo:
  * @type: the current probe type
  * @id: the id of the probe
- * @data: (allow-none): type specific data, check the @type field to know the
+ * @data: (nullable): type specific data, check the @type field to know the
  *    datatype.  This field can be %NULL.
  * @offset: offset of pull probe, this field is valid when @type contains
  *    #GST_PAD_PROBE_TYPE_PULL
@@ -612,6 +618,21 @@ struct _GstPadProbeInfo
 #define GST_PAD_PROBE_INFO_OFFSET(d)       ((d)->offset)
 #define GST_PAD_PROBE_INFO_SIZE(d)         ((d)->size)
 
+GST_API
+GstPadProbeType gst_pad_probe_info_get_type       (GstPadProbeInfo * info);
+
+GST_API
+gulong         gst_pad_probe_info_get_id          (GstPadProbeInfo * info);
+
+GST_API
+guint64        gst_pad_probe_info_get_offset      (GstPadProbeInfo * info);
+
+GST_API
+gsize          gst_pad_probe_info_get_size        (GstPadProbeInfo * info);
+
+GST_API
+GstFlowReturn  gst_pad_probe_info_get_flow_return  (GstPadProbeInfo * info);
+
 GST_API
 GstEvent*      gst_pad_probe_info_get_event       (GstPadProbeInfo * info);
 
@@ -624,6 +645,22 @@ GstBuffer*     gst_pad_probe_info_get_buffer      (GstPadProbeInfo * info);
 GST_API
 GstBufferList* gst_pad_probe_info_get_buffer_list (GstPadProbeInfo * info);
 
+GST_API
+void           gst_pad_probe_info_set_event       (GstPadProbeInfo * info,
+                                                   GstEvent        * event);
+
+GST_API
+void           gst_pad_probe_info_set_buffer      (GstPadProbeInfo * info,
+                                                   GstBuffer       * buffer);
+
+GST_API
+void           gst_pad_probe_info_set_buffer_list (GstPadProbeInfo * info,
+                                                   GstBufferList   * list);
+
+GST_API
+void           gst_pad_probe_info_set_flow_return  (GstPadProbeInfo * info,
+                                                    GstFlowReturn     flow_ret);
+
 /**
  * GstPadProbeCallback:
  * @pad: the #GstPad that is blocked
@@ -643,7 +680,7 @@ typedef GstPadProbeReturn   (*GstPadProbeCallback)   (GstPad *pad, GstPadProbeIn
 /**
  * GstPadStickyEventsForeachFunction:
  * @pad: the #GstPad.
- * @event: (allow-none): a sticky #GstEvent.
+ * @event: (inout) (nullable): a sticky #GstEvent.
  * @user_data: the #gpointer to optional user data.
  *
  * Callback used by gst_pad_sticky_events_foreach().
@@ -692,7 +729,7 @@ typedef gboolean  (*GstPadStickyEventsForeachFunction) (GstPad *pad, GstEvent **
  * @GST_PAD_FLAG_ACCEPT_TEMPLATE: the default accept-caps handler will use
  *                      the template pad caps instead of query caps to
  *                      compare with the accept caps. Use this in combination
- *                      with %GST_PAD_FLAG_ACCEPT_INTERSECT. (Since 1.6)
+ *                      with %GST_PAD_FLAG_ACCEPT_INTERSECT. (Since: 1.6)
  * @GST_PAD_FLAG_LAST: offset to define more flags
  *
  * Pad state flags
@@ -1243,6 +1280,34 @@ struct _GstPadClass {
  * when buffers or serialized downstream events are pushed on a pad.
  */
 #define GST_PAD_STREAM_LOCK(pad)        g_rec_mutex_lock(GST_PAD_GET_STREAM_LOCK(pad))
+
+/**
+ * GST_PAD_STREAM_AUTO_LOCK
+ * @pad: a #GstPad
+ * @var: a variable name to be declared
+ *
+ * Declare a #GRecMutexLocker variable with g_autoptr() and lock the pad. The
+ * recursive mutex will be unlocked automatically when leaving the scope.
+ *
+ * ``` c
+ * {
+ *   GST_PAD_STREAM_AUTO_LOCK (pad, locker);
+ *
+ *   gst_pad_push_event(pad, event1);
+ *   if (cond) {
+ *     // No need to unlock
+ *     return;
+ *   }
+ *
+ *   // Unlock before end of scope
+ *   g_clear_pointer (&locker, g_rec_mutex_locker_free);
+ *   gst_pad_push_event(pad, event2);
+ * }
+ * ```
+ * Since: 1.24.0
+ */
+#define GST_PAD_STREAM_AUTO_LOCK(pad, var) g_autoptr(GRecMutexLocker) G_GNUC_UNUSED var = g_rec_mutex_locker_new(GST_PAD_GET_STREAM_LOCK(pad))
+
 /**
  * GST_PAD_STREAM_TRYLOCK:
  * @pad: a #GstPad
@@ -1279,13 +1344,13 @@ GType			gst_pad_get_type			(void);
 /* creating pads */
 
 GST_API
-GstPad*			gst_pad_new				(const gchar *name, GstPadDirection direction);
+GstPad*			gst_pad_new				(const gchar *name, GstPadDirection direction) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstPad*			gst_pad_new_from_template		(GstPadTemplate *templ, const gchar *name);
+GstPad*			gst_pad_new_from_template		(GstPadTemplate *templ, const gchar *name) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstPad*			gst_pad_new_from_static_template	(GstStaticPadTemplate *templ, const gchar *name);
+GstPad*			gst_pad_new_from_static_template	(GstStaticPadTemplate *templ, const gchar *name) G_GNUC_WARN_UNUSED_RESULT;
 
 
 /**
@@ -1354,14 +1419,14 @@ GST_API
 gpointer		gst_pad_get_element_private		(GstPad *pad);
 
 GST_API
-GstPadTemplate*		gst_pad_get_pad_template		(GstPad *pad);
+GstPadTemplate*		gst_pad_get_pad_template		(GstPad *pad) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 GstFlowReturn           gst_pad_store_sticky_event              (GstPad *pad, GstEvent *event);
 
 GST_API
 GstEvent*               gst_pad_get_sticky_event                (GstPad *pad, GstEventType event_type,
-                                                                 guint idx);
+                                                                 guint idx) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 void                    gst_pad_sticky_events_foreach           (GstPad *pad, GstPadStickyEventsForeachFunction foreach_func, gpointer user_data);
@@ -1446,15 +1511,15 @@ GST_API
 gboolean		gst_pad_is_linked			(GstPad *pad);
 
 GST_API
-GstPad*			gst_pad_get_peer			(GstPad *pad);
+GstPad*			gst_pad_get_peer			(GstPad *pad) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstCaps*                gst_pad_get_pad_template_caps		(GstPad *pad);
+GstCaps*                gst_pad_get_pad_template_caps		(GstPad *pad) G_GNUC_WARN_UNUSED_RESULT;
 
 /* capsnego function for linked/unlinked pads */
 
 GST_API
-GstCaps *		gst_pad_get_current_caps                (GstPad * pad);
+GstCaps *		gst_pad_get_current_caps                (GstPad * pad) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 gboolean		gst_pad_has_current_caps                (GstPad * pad);
@@ -1462,7 +1527,7 @@ gboolean		gst_pad_has_current_caps                (GstPad * pad);
 /* capsnego for linked pads */
 
 GST_API
-GstCaps *		gst_pad_get_allowed_caps		(GstPad * pad);
+GstCaps *		gst_pad_get_allowed_caps		(GstPad * pad) G_GNUC_WARN_UNUSED_RESULT;
 
 /* pad offsets */
 
@@ -1529,13 +1594,16 @@ void                    gst_pad_set_iterate_internal_links_function_full (GstPad
                                                                  GDestroyNotify notify);
 
 GST_API
-GstIterator *           gst_pad_iterate_internal_links          (GstPad * pad);
+GstIterator *           gst_pad_iterate_internal_links          (GstPad * pad) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator *           gst_pad_iterate_internal_links_default  (GstPad * pad, GstObject *parent);
+GstIterator *           gst_pad_iterate_internal_links_default  (GstPad * pad, GstObject *parent) G_GNUC_WARN_UNUSED_RESULT;
 
 #define gst_pad_set_iterate_internal_links_function(p,f) gst_pad_set_iterate_internal_links_function_full((p),(f),NULL,NULL)
 
+GST_API
+GstPad *                gst_pad_get_single_internal_link        (GstPad * pad) G_GNUC_WARN_UNUSED_RESULT;
+
 /* generic query function */
 
 GST_API
@@ -1560,9 +1628,7 @@ GST_API
 gboolean		gst_pad_forward                         (GstPad *pad, GstPadForwardFunction forward,
 								 gpointer user_data);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstPad, gst_object_unref)
-#endif
 
 G_END_DECLS
 
