@@ -375,7 +375,7 @@ GST_API
 GstPlugin *		gst_plugin_load_file		(const gchar *filename, GError** error);
 
 GST_API
-GstPlugin *             gst_plugin_load                 (GstPlugin *plugin);
+GstPlugin *             gst_plugin_load                 (GstPlugin *plugin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 GstPlugin *             gst_plugin_load_by_name         (const gchar *name);
@@ -392,12 +392,28 @@ void                    gst_plugin_add_dependency_simple (GstPlugin   * plugin,
                                                           const gchar * paths,
                                                           const gchar * names,
                                                           GstPluginDependencyFlags flags);
+GST_API
+void                    gst_plugin_add_status_error      (GstPlugin   * plugin,
+                                                          const gchar * message);
+GST_API
+void                    gst_plugin_add_status_warning    (GstPlugin   * plugin,
+                                                          const gchar * message);
+GST_API
+void                    gst_plugin_add_status_info       (GstPlugin   * plugin,
+                                                          const gchar * message);
+GST_API
+gchar **                gst_plugin_get_status_errors     (GstPlugin   * plugin) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+gchar **                gst_plugin_get_status_warnings   (GstPlugin   * plugin) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+gchar **                gst_plugin_get_status_infos      (GstPlugin   * plugin) G_GNUC_WARN_UNUSED_RESULT;
+
 GST_API
 void                    gst_plugin_list_free (GList *list);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstPlugin, gst_object_unref)
-#endif
 
 G_END_DECLS
 
