@@ -27,6 +27,7 @@ G_BEGIN_DECLS
 GST_API
 GType gst_promise_get_type(void);
 #define GST_TYPE_PROMISE            (gst_promise_get_type())
+#define GST_IS_PROMISE(obj)         (GST_IS_MINI_OBJECT_TYPE (obj, GST_TYPE_PROMISE))
 #define GST_PROMISE(obj)            ((GstPromise *) obj)
 
 typedef struct _GstPromise GstPromise;
@@ -74,11 +75,11 @@ struct _GstPromise
 };
 
 GST_API
-GstPromise *            gst_promise_new                     (void);
+GstPromise *            gst_promise_new                     (void) G_GNUC_WARN_UNUSED_RESULT;
 GST_API
 GstPromise *            gst_promise_new_with_change_func    (GstPromiseChangeFunc func,
                                                              gpointer user_data,
-                                                             GDestroyNotify notify);
+                                                             GDestroyNotify notify) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 GstPromiseResult        gst_promise_wait                    (GstPromise * promise);
@@ -93,40 +94,36 @@ void                    gst_promise_expire                  (GstPromise * promis
 GST_API
 const GstStructure *    gst_promise_get_reply               (GstPromise * promise);
 
-/**
- * gst_promise_ref:
- * @promise: a #GstPromise.
- *
- * Increases the refcount of the given @promise by one.
- *
- * Returns: (transfer full): @promise
- *
- * Since: 1.14
- */
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 static inline GstPromise *
 gst_promise_ref (GstPromise * promise)
 {
   return (GstPromise *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (promise));
 }
 
-/**
- * gst_promise_unref:
- * @promise: (transfer full): a #GstPromise.
- *
- * Decreases the refcount of the promise. If the refcount reaches 0, the
- * promise will be freed.
- *
- * Since: 1.14
- */
 static inline void
 gst_promise_unref (GstPromise * promise)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (promise));
 }
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+static inline void
+gst_clear_promise (GstPromise ** promise_ptr)
+{
+  gst_clear_mini_object ((GstMiniObject **) promise_ptr);
+}
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+GstPromise *  gst_promise_ref (GstPromise * promise);
+
+GST_API
+void          gst_promise_unref (GstPromise * promise);
+
+GST_API
+void          gst_clear_promise (GstPromise ** promise_ptr);
+#endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstPromise, gst_promise_unref)
-#endif
 
 G_END_DECLS
 
