@@ -58,6 +58,7 @@
 #include <gst/gsttypefindfactory.h>
 #include <gst/gstdeviceproviderfactory.h>
 #include <gst/gstdynamictypefactory.h>
+#include <gst/gstmetafactory.h>
 #include <gst/gsturi.h>
 #include <gst/gstinfo.h>
 #include <gst/gstenumtypes.h>
@@ -103,7 +104,7 @@ typedef struct BinaryRegistryCache
 static BinaryRegistryCache *
 gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
 {
-  BinaryRegistryCache *cache = g_slice_new0 (BinaryRegistryCache);
+  BinaryRegistryCache *cache = g_new0 (BinaryRegistryCache, 1);
   cache->location = location;
   return cache;
 }
@@ -157,7 +158,7 @@ gst_registry_binary_cache_finish (BinaryRegistryCache * cache, gboolean success)
   }
 
   g_free (cache->mem);
-  g_slice_free (BinaryRegistryCache, cache);
+  g_free (cache);
   return ret;
 }
 
@@ -173,7 +174,7 @@ typedef struct BinaryRegistryCache
 static BinaryRegistryCache *
 gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
 {
-  BinaryRegistryCache *cache = g_slice_new0 (BinaryRegistryCache);
+  BinaryRegistryCache *cache = g_new0 (BinaryRegistryCache, 1);
   int fd;
 
   cache->location = location;
@@ -203,7 +204,7 @@ gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
     if (fd == -1) {
       GST_DEBUG ("g_mkstemp() failed: %s", g_strerror (errno));
       g_free (cache->tmp_location);
-      g_slice_free (BinaryRegistryCache, cache);
+      g_free (cache);
       return NULL;
     }
 
@@ -218,7 +219,7 @@ gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
     GST_DEBUG ("fdopen() failed: %s", g_strerror (errno));
     close (fd);
     g_free (cache->tmp_location);
-    g_slice_free (BinaryRegistryCache, cache);
+    g_free (cache);
     return NULL;
   }
 
@@ -310,7 +311,7 @@ gst_registry_binary_cache_finish (BinaryRegistryCache * cache, gboolean success)
   }
 
   g_free (cache->tmp_location);
-  g_slice_free (BinaryRegistryCache, cache);
+  g_free (cache);
   GST_INFO ("Wrote binary registry cache");
   return TRUE;
 
@@ -324,7 +325,7 @@ fail_after_fclose:
   {
     g_unlink (cache->tmp_location);
     g_free (cache->tmp_location);
-    g_slice_free (BinaryRegistryCache, cache);
+    g_free (cache);
     return FALSE;
   }
 fflush_failed:
@@ -591,6 +592,7 @@ priv_gst_registry_binary_read_cache (GstRegistry * registry,
   GST_TYPE_TYPE_FIND_FACTORY;
   GST_TYPE_DEVICE_PROVIDER_FACTORY;
   GST_TYPE_DYNAMIC_TYPE_FACTORY;
+  GST_TYPE_META_FACTORY;
 
 #ifndef GST_DISABLE_GST_DEBUG
   timer = g_timer_new ();
