@@ -172,12 +172,12 @@ GType           gst_task_get_type       (void);
 
 GST_API
 GstTask*        gst_task_new            (GstTaskFunction func,
-                                         gpointer user_data, GDestroyNotify notify);
+                                         gpointer user_data, GDestroyNotify notify) G_GNUC_WARN_UNUSED_RESULT;
 GST_API
 void            gst_task_set_lock       (GstTask *task, GRecMutex *mutex);
 
 GST_API
-GstTaskPool *   gst_task_get_pool       (GstTask *task);
+GstTaskPool *   gst_task_get_pool       (GstTask *task) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 void            gst_task_set_pool       (GstTask *task, GstTaskPool *pool);
@@ -207,12 +207,13 @@ gboolean        gst_task_stop           (GstTask *task);
 GST_API
 gboolean        gst_task_pause          (GstTask *task);
 
+GST_API
+gboolean        gst_task_resume         (GstTask *task);
+
 GST_API
 gboolean        gst_task_join           (GstTask *task);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstTask, gst_object_unref)
-#endif
 
 G_END_DECLS
 
