@@ -141,7 +141,7 @@
 #include <string.h>
 
 #include "../../../gst/gst_private.h"
-#include "../../../gst/gst-i18n-lib.h"
+#include <glib/gi18n-lib.h>
 #include "../../../gst/glib-compat-private.h"
 #include "gstbasetransform.h"
 
@@ -386,6 +386,7 @@ gst_base_transform_init (GstBaseTransform * trans,
       gst_element_class_get_pad_template (GST_ELEMENT_CLASS (bclass), "sink");
   g_return_if_fail (pad_template != NULL);
   trans->sinkpad = gst_pad_new_from_template (pad_template, "sink");
+  GST_PAD_SET_ACCEPT_INTERSECT (trans->sinkpad);
   gst_pad_set_event_function (trans->sinkpad,
       GST_DEBUG_FUNCPTR (gst_base_transform_sink_event));
   gst_pad_set_chain_function (trans->sinkpad,
@@ -475,7 +476,7 @@ gst_base_transform_transform_caps (GstBaseTransform * trans,
     GST_LOG_OBJECT (trans, "  to: %" GST_PTR_FORMAT, ret);
 
 #ifdef GST_ENABLE_EXTRA_CHECKS
-    if (filter) {
+    if (ret && filter) {
       if (!gst_caps_is_subset (ret, filter)) {
         GstCaps *intersection;
 
@@ -655,7 +656,7 @@ gst_base_transform_query_caps (GstBaseTransform * trans, GstPad * pad,
     if (peerfilter) {
       if (!gst_caps_is_empty (peerfilter)) {
         /* and filter against the template of the other pad */
-        GST_DEBUG_OBJECT (pad, "our template  %" GST_PTR_FORMAT, otempl);
+        GST_DEBUG_OBJECT (pad, "other template  %" GST_PTR_FORMAT, otempl);
         /* We keep the caps sorted like the returned caps */
         temp =
             gst_caps_intersect_full (peerfilter, otempl,
@@ -687,7 +688,7 @@ gst_base_transform_query_caps (GstBaseTransform * trans, GstPad * pad,
     GST_DEBUG_OBJECT (pad, "peer caps  %" GST_PTR_FORMAT, peercaps);
 
     /* filtered against our padtemplate on the other side */
-    GST_DEBUG_OBJECT (pad, "our template  %" GST_PTR_FORMAT, otempl);
+    GST_DEBUG_OBJECT (pad, "other template  %" GST_PTR_FORMAT, otempl);
     temp = gst_caps_intersect_full (peercaps, otempl, GST_CAPS_INTERSECT_FIRST);
     GST_DEBUG_OBJECT (pad, "intersected %" GST_PTR_FORMAT, temp);
   } else {
@@ -810,7 +811,8 @@ gst_base_transform_default_decide_allocation (GstBaseTransform * trans,
 
     /* by default we remove all metadata, subclasses should implement a
      * filter_meta function */
-    if (gst_meta_api_type_has_tag (api, _gst_meta_tag_memory)) {
+    if (gst_meta_api_type_has_tag (api, _gst_meta_tag_memory)
+        || gst_meta_api_type_has_tag (api, _gst_meta_tag_memory_reference)) {
       /* remove all memory dependent metadata because we are going to have to
        * allocate different memory for input and output. */
       GST_LOG_OBJECT (trans, "removing memory specific metadata %s",
@@ -873,16 +875,23 @@ gst_base_transform_default_decide_allocation (GstBaseTransform * trans,
       /* If change are not acceptable, fallback to generic pool */
       if (!gst_buffer_pool_config_validate_params (config, outcaps, size, min,
               max)) {
-        GST_DEBUG_OBJECT (trans, "unsupported pool, making new pool");
-
-        gst_object_unref (pool);
-        pool = gst_buffer_pool_new ();
-        gst_buffer_pool_config_set_params (config, outcaps, size, min, max);
-        gst_buffer_pool_config_set_allocator (config, allocator, &params);
+        gst_structure_free (config);
+        gst_clear_object (&pool);
+      } else if (!gst_buffer_pool_set_config (pool, config)) {
+        gst_clear_object (&pool);
       }
 
-      if (!gst_buffer_pool_set_config (pool, config))
-        goto config_failed;
+      if (!pool) {
+        GST_DEBUG_OBJECT (trans, "unsupported pool, making new pool");
+
+        pool = gst_buffer_pool_new ();
+        config = gst_buffer_pool_get_config (pool);
+        gst_buffer_pool_config_set_params (config, outcaps, size, min, max);
+        gst_buffer_pool_config_set_allocator (config, allocator, &params);
+
+        if (!gst_buffer_pool_set_config (pool, config))
+          goto config_failed;
+      }
     }
   }
 
@@ -1262,10 +1271,17 @@ gst_base_transform_acceptcaps_default (GstBaseTransform * trans,
   otempl = gst_pad_get_pad_template_caps (otherpad);
 
   /* get all the formats we can handle on this pad */
-  GST_DEBUG_OBJECT (trans, "intersect with pad template: %" GST_PTR_FORMAT,
-      templ);
-  if (!gst_caps_can_intersect (caps, templ))
-    goto reject_caps;
+  if (GST_PAD_IS_ACCEPT_INTERSECT (trans->sinkpad)) {
+    GST_DEBUG_OBJECT (trans, "intersect with pad template: %" GST_PTR_FORMAT,
+        templ);
+    if (!gst_caps_can_intersect (caps, templ))
+      goto reject_caps;
+  } else {
+    GST_DEBUG_OBJECT (trans, "subset with pad template: %" GST_PTR_FORMAT,
+        templ);
+    if (!gst_caps_is_subset (caps, templ))
+      goto reject_caps;
+  }
 
   GST_DEBUG_OBJECT (trans, "trying to transform with filter: %"
       GST_PTR_FORMAT " (the other pad template)", otempl);
@@ -1595,6 +1611,10 @@ gst_base_transform_default_query (GstBaseTransform * trans,
 
       gst_query_parse_caps (query, &filter);
       caps = gst_base_transform_query_caps (trans, pad, filter);
+      if (!caps) {
+        GST_WARNING_OBJECT (pad, "no caps can be handled by this pad");
+        caps = gst_caps_new_empty ();
+      }
       gst_query_set_caps_result (query, caps);
       gst_caps_unref (caps);
       ret = TRUE;
@@ -1762,7 +1782,8 @@ foreach_metadata (GstBuffer * inbuf, GstMeta ** meta, gpointer user_data)
 
   klass = GST_BASE_TRANSFORM_GET_CLASS (trans);
 
-  if (gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory)) {
+  if (gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory)
+      || gst_meta_api_type_has_tag (info->api, _gst_meta_tag_memory_reference)) {
     /* never call the transform_meta with memory specific metadata */
     GST_DEBUG_OBJECT (trans, "not copying memory specific metadata %s",
         g_type_name (info->api));
@@ -2030,6 +2051,7 @@ default_submit_input_buffer (GstBaseTransform * trans, gboolean is_discont,
   GstFlowReturn ret = GST_FLOW_OK;
   GstClockTime running_time;
   GstClockTime timestamp;
+  gboolean qos_enabled;
 
   if (G_UNLIKELY (!gst_base_transform_reconfigure_unlocked (trans)))
     goto not_negotiated;
@@ -2052,6 +2074,14 @@ default_submit_input_buffer (GstBaseTransform * trans, gboolean is_discont,
   if (!priv->negotiated && !priv->passthrough && (bclass->set_caps != NULL))
     goto not_negotiated;
 
+  GST_OBJECT_LOCK (trans);
+  qos_enabled = priv->qos_enabled;
+  GST_OBJECT_UNLOCK (trans);
+
+  /* Skip all qos handling if disabled */
+  if (!qos_enabled)
+    goto no_qos;
+
   /* can only do QoS if the segment is in TIME */
   if (trans->segment.format != GST_FORMAT_TIME)
     goto no_qos;
@@ -2073,8 +2103,7 @@ default_submit_input_buffer (GstBaseTransform * trans, gboolean is_discont,
     proportion = priv->proportion;
     /* check for QoS, don't perform conversion for buffers
      * that are known to be late. */
-    need_skip = priv->qos_enabled &&
-        earliest_time != -1 && running_time <= earliest_time;
+    need_skip = earliest_time != -1 && running_time <= earliest_time;
     GST_OBJECT_UNLOCK (trans);
 
     if (need_skip) {
