@@ -137,7 +137,7 @@ typedef enum {
  * @pos: position in the buffer
  * @segment: last segment received.
  * @dts: the signed version of the DTS converted to running time. To access
- *       this memeber, use %GST_COLLECT_PADS_DTS macro. (Since 1.6)
+ *       this member, use %GST_COLLECT_PADS_DTS macro. (Since: 1.6)
  *
  * Structure used by the collect_pads.
  */
@@ -253,7 +253,7 @@ typedef gboolean (*GstCollectPadsQueryFunction)        (GstCollectPads *pads, Gs
  * @pads: a #GstCollectPads
  * @data: a #GstCollectData
  * @inbuffer: (transfer full): the input #GstBuffer
- * @outbuffer: the output #GstBuffer
+ * @outbuffer: (out): the output #GstBuffer
  * @user_data: user data
  *
  * A function that will be called when @inbuffer is received on the pad managed
@@ -346,7 +346,7 @@ GType           gst_collect_pads_get_type (void);
 /* creating the object */
 
 GST_BASE_API
-GstCollectPads* gst_collect_pads_new      (void);
+GstCollectPads* gst_collect_pads_new      (void) G_GNUC_WARN_UNUSED_RESULT;
 
 /* set the callbacks */
 
@@ -402,10 +402,10 @@ void            gst_collect_pads_set_flushing  (GstCollectPads *pads, gboolean f
 /* get collected buffers */
 
 GST_BASE_API
-GstBuffer*      gst_collect_pads_peek          (GstCollectPads *pads, GstCollectData *data);
+GstBuffer*      gst_collect_pads_peek          (GstCollectPads *pads, GstCollectData *data) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_BASE_API
-GstBuffer*      gst_collect_pads_pop           (GstCollectPads *pads, GstCollectData *data);
+GstBuffer*      gst_collect_pads_pop           (GstCollectPads *pads, GstCollectData *data) G_GNUC_WARN_UNUSED_RESULT;
 
 /* get collected bytes */
 
@@ -417,10 +417,10 @@ guint           gst_collect_pads_flush         (GstCollectPads *pads, GstCollect
                                                 guint size);
 GST_BASE_API
 GstBuffer*      gst_collect_pads_read_buffer   (GstCollectPads * pads, GstCollectData * data,
-                                                guint size);
+                                                guint size) G_GNUC_WARN_UNUSED_RESULT;
 GST_BASE_API
 GstBuffer*      gst_collect_pads_take_buffer   (GstCollectPads * pads, GstCollectData * data,
-                                                guint size);
+                                                guint size) G_GNUC_WARN_UNUSED_RESULT;
 
 /* setting and unsetting waiting mode */
 
@@ -449,9 +449,7 @@ gboolean        gst_collect_pads_query_default (GstCollectPads * pads, GstCollec
                                                 GstQuery * query, gboolean discard);
 
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstCollectPads, gst_object_unref)
-#endif
 
 G_END_DECLS
 
