@@ -79,10 +79,10 @@ GST_CHECK_API
 GType         gst_test_clock_get_type (void);
 
 GST_CHECK_API
-GstClock *    gst_test_clock_new (void);
+GstClock *    gst_test_clock_new (void) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_CHECK_API
-GstClock *    gst_test_clock_new_with_start_time (GstClockTime start_time);
+GstClock *    gst_test_clock_new_with_start_time (GstClockTime start_time) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_CHECK_API
 void          gst_test_clock_set_time (GstTestClock * test_clock,
@@ -111,7 +111,7 @@ void          gst_test_clock_wait_for_pending_id_count (GstTestClock * test_cloc
                                                         guint          count);
 
 GST_CHECK_API
-GstClockID    gst_test_clock_process_next_clock_id (GstTestClock * test_clock);
+GstClockID    gst_test_clock_process_next_clock_id (GstTestClock * test_clock) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_CHECK_API
 GstClockTime  gst_test_clock_get_next_entry_time   (GstTestClock * test_clock);
@@ -127,6 +127,10 @@ gboolean      gst_test_clock_timed_wait_for_multiple_pending_ids (GstTestClock *
                                                                   guint          timeout_ms,
                                                                   GList       ** pending_list);
 
+GST_CHECK_API
+gboolean      gst_test_clock_process_id (GstTestClock * test_clock,
+                                         GstClockID pending_id);
+
 GST_CHECK_API
 guint         gst_test_clock_process_id_list (GstTestClock * test_clock,
                                               const GList  * pending_list);
@@ -137,9 +141,7 @@ GstClockTime  gst_test_clock_id_list_get_latest_time (const GList * pending_list
 GST_CHECK_API
 gboolean      gst_test_clock_crank (GstTestClock * test_clock);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstTestClock, gst_object_unref)
-#endif
 
 G_END_DECLS
 
