@@ -14,11 +14,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
-#include "libcompat.h"
+#include "libcompat/libcompat.h"
 
 #include <sys/types.h>
 #include <time.h>
@@ -29,6 +29,8 @@
 #include <signal.h>
 #include <setjmp.h>
 
+#include <glib.h>
+
 #include "internal-check.h"
 #include "check_error.h"
 #include "check_list.h"
@@ -59,7 +61,9 @@ enum tf_type
 static void srunner_run_init (SRunner * sr, enum print_output print_mode);
 static void srunner_run_end (SRunner * sr, enum print_output print_mode);
 static void srunner_iterate_suites (SRunner * sr,
-    const char *sname, const char *tcname, enum print_output print_mode);
+    const char *sname, const char *tcname,
+    const char *include_tags,
+    const char *exclude_tags, enum print_output print_mode);
 static void srunner_iterate_tcase_tfuns (SRunner * sr, TCase * tc);
 static void srunner_add_failure (SRunner * sr, TestResult * tf);
 static TestResult *srunner_run_setup (List * func_list,
@@ -93,11 +97,8 @@ static int waserror (int status, int expected_signal);
 
 static int alarm_received;
 static pid_t group_pid;
-
-#if defined(HAVE_SIGACTION) && defined(HAVE_FORK)
-static struct sigaction old_action[3];
-static struct sigaction new_action[3];
-#endif /* HAVE_SIGACTION && HAVE_FORK */
+static struct sigaction sigint_old_action;
+static struct sigaction sigterm_old_action;
 
 static void CK_ATTRIBUTE_UNUSED
 sig_handler (int sig_nr)
@@ -105,29 +106,24 @@ sig_handler (int sig_nr)
   switch (sig_nr) {
     case SIGALRM:
       alarm_received = 1;
-      killpg (group_pid, SIGKILL);
+      killpg (group_pid, SIGABRT);
       break;
     case SIGTERM:
-    case SIGINT:{
+    case SIGINT:
+    {
       pid_t own_group_pid;
-      int idx;
-      int child_sig;
+      int child_sig = SIGTERM;
 
       if (sig_nr == SIGINT) {
-        idx = 1;
         child_sig = SIGKILL;
-      } else {                  /* if (sig_nr == SIGTERM) */
-
-        idx = 2;
-        child_sig = SIGTERM;
+        sigaction (SIGINT, &sigint_old_action, NULL);
+      } else {
+        sigaction (SIGTERM, &sigterm_old_action, NULL);
       }
 
       killpg (group_pid, child_sig);
 
-      /* Restore old signal handler... */
-      sigaction (sig_nr, &old_action[idx], NULL);
-
-      /* ... and call it. POSIX says that calling killpg(0)
+      /* POSIX says that calling killpg(0)
        * does not necessarily mean to call it on the callers
        * group pid! */
       own_group_pid = getpgrp ();
@@ -164,14 +160,20 @@ srunner_run_end (SRunner * sr, enum print_output CK_ATTRIBUTE_UNUSED print_mode)
 static void
 srunner_iterate_suites (SRunner * sr,
     const char *sname, const char *tcname,
-    enum print_output CK_ATTRIBUTE_UNUSED print_mode)
+    const char *include_tags,
+    const char *exclude_tags, enum print_output CK_ATTRIBUTE_UNUSED print_mode)
 {
+  List *include_tag_lst;
+  List *exclude_tag_lst;
   List *slst;
   List *tcl;
   TCase *tc;
 
   slst = sr->slst;
 
+  include_tag_lst = tag_string_to_list (include_tags);
+  exclude_tag_lst = tag_string_to_list (exclude_tags);
+
   for (check_list_front (slst); !check_list_at_end (slst);
       check_list_advance (slst)) {
     Suite *s = (Suite *) check_list_val (slst);
@@ -191,12 +193,27 @@ srunner_iterate_suites (SRunner * sr,
       if ((tcname != NULL) && (strcmp (tcname, tc->name) != 0)) {
         continue;
       }
+      if (include_tags != NULL) {
+        if (!tcase_matching_tag (tc, include_tag_lst)) {
+          continue;
+        }
+      }
+      if (exclude_tags != NULL) {
+        if (tcase_matching_tag (tc, exclude_tag_lst)) {
+          continue;
+        }
+      }
 
       srunner_run_tcase (sr, tc);
     }
 
     log_suite_end (sr, s);
   }
+
+  check_list_apply (include_tag_lst, free);
+  check_list_apply (exclude_tag_lst, free);
+  check_list_free (include_tag_lst);
+  check_list_free (exclude_tag_lst);
 }
 
 static void
@@ -369,7 +386,8 @@ tcase_run_tfun_nofork (SRunner * sr, TCase * tc, TF * tfun, int i)
 {
   TestResult *tr;
   struct timespec ts_start = { 0, 0 }, ts_end = {
-  0, 0};
+    0, 0
+  };
 
   tr = tcase_run_checked_setup (sr, tc);
   if (tr == NULL) {
@@ -431,7 +449,8 @@ tcase_run_tfun_fork (SRunner * sr, TCase * tc, TF * tfun, int i)
   pid_t pid;
   int status = 0;
   struct timespec ts_start = { 0, 0 }, ts_end = {
-  0, 0};
+    0, 0
+  };
 
   timer_t timerid;
   struct itimerspec timer_spec;
@@ -451,6 +470,7 @@ tcase_run_tfun_fork (SRunner * sr, TCase * tc, TF * tfun, int i)
     clock_gettime (check_get_clockid (), &ts_end);
     tcase_run_checked_teardown (tc);
     send_duration_info (DIFF_IN_USEC (ts_start, ts_end));
+    g_thread_pool_stop_unused_threads ();
     exit (EXIT_SUCCESS);
   } else {
     group_pid = pid;
@@ -649,6 +669,7 @@ srunner_fork_status (SRunner * sr)
       return CK_FORK;
 #else /* HAVE_FORK */
       eprintf ("This version does not support fork", __FILE__, __LINE__);
+      /* Ignoring, as Check is not compiled with fork support. */
       return CK_NOFORK;
 #endif /* HAVE_FORK */
     }
@@ -663,6 +684,8 @@ srunner_set_fork_status (SRunner * sr, enum fork_status fstat)
   /* If fork() is unavailable, do not allow a fork mode to be set */
   if (fstat != CK_NOFORK) {
     eprintf ("This version does not support fork", __FILE__, __LINE__);
+    /* Overriding, as Check is not compiled with fork support. */
+    fstat = CK_NOFORK;
   }
 #endif /* ! HAVE_FORK */
   sr->fstat = fstat;
@@ -677,15 +700,27 @@ srunner_run_all (SRunner * sr, enum print_output print_mode)
 }
 
 void
-srunner_run (SRunner * sr, const char *sname, const char *tcname,
+srunner_run_tagged (SRunner * sr, const char *sname, const char *tcname,
+    const char *include_tags, const char *exclude_tags,
     enum print_output print_mode)
 {
-  /* Get the selected test suite and test case from the
+#if defined(HAVE_SIGACTION) && defined(HAVE_FORK)
+  static struct sigaction sigalarm_old_action;
+  static struct sigaction sigalarm_new_action;
+  static struct sigaction sigint_new_action;
+  static struct sigaction sigterm_new_action;
+#endif /* HAVE_SIGACTION && HAVE_FORK */
+
+  /*  Get the selected test suite and test case from the
      environment.  */
   if (!tcname)
     tcname = getenv ("CK_RUN_CASE");
   if (!sname)
     sname = getenv ("CK_RUN_SUITE");
+  if (!include_tags)
+    include_tags = getenv ("CK_INCLUDE_TAGS");
+  if (!exclude_tags)
+    exclude_tags = getenv ("CK_EXCLUDE_TAGS");
 
   if (sr == NULL)
     return;
@@ -694,24 +729,36 @@ srunner_run (SRunner * sr, const char *sname, const char *tcname,
         __FILE__, __LINE__, print_mode);
   }
 #if defined(HAVE_SIGACTION) && defined(HAVE_FORK)
-  memset (&new_action, 0, sizeof new_action);
-  new_action[0].sa_handler = sig_handler;
-  sigaction (SIGALRM, &new_action[0], &old_action[0]);
-  new_action[1].sa_handler = sig_handler;
-  sigaction (SIGINT, &new_action[1], &old_action[1]);
-  new_action[2].sa_handler = sig_handler;
-  sigaction (SIGTERM, &new_action[2], &old_action[2]);
+  memset (&sigalarm_new_action, 0, sizeof (sigalarm_new_action));
+  sigalarm_new_action.sa_handler = sig_handler;
+  sigaction (SIGALRM, &sigalarm_new_action, &sigalarm_old_action);
+
+  memset (&sigint_new_action, 0, sizeof (sigint_new_action));
+  sigint_new_action.sa_handler = sig_handler;
+  sigaction (SIGINT, &sigint_new_action, &sigint_old_action);
+
+  memset (&sigterm_new_action, 0, sizeof (sigterm_new_action));
+  sigterm_new_action.sa_handler = sig_handler;
+  sigaction (SIGTERM, &sigterm_new_action, &sigterm_old_action);
 #endif /* HAVE_SIGACTION && HAVE_FORK */
   srunner_run_init (sr, print_mode);
-  srunner_iterate_suites (sr, sname, tcname, print_mode);
+  srunner_iterate_suites (sr, sname, tcname, include_tags, exclude_tags,
+      print_mode);
   srunner_run_end (sr, print_mode);
 #if defined(HAVE_SIGACTION) && defined(HAVE_FORK)
-  sigaction (SIGALRM, &old_action[0], NULL);
-  sigaction (SIGINT, &old_action[1], NULL);
-  sigaction (SIGTERM, &old_action[2], NULL);
+  sigaction (SIGALRM, &sigalarm_old_action, NULL);
+  sigaction (SIGINT, &sigint_old_action, NULL);
+  sigaction (SIGTERM, &sigterm_old_action, NULL);
 #endif /* HAVE_SIGACTION && HAVE_FORK */
 }
 
+void
+srunner_run (SRunner * sr, const char *sname, const char *tcname,
+    enum print_output print_mode)
+{
+  srunner_run_tagged (sr, sname, tcname, NULL, NULL, print_mode);
+}
+
 pid_t
 check_fork (void)
 {
@@ -742,11 +789,15 @@ check_waitpid_and_exit (pid_t pid CK_ATTRIBUTE_UNUSED)
     }
     while (pid_w == -1);
     if (waserror (status, 0)) {
+      g_thread_pool_stop_unused_threads ();
       exit (EXIT_FAILURE);
     }
   }
+  g_thread_pool_stop_unused_threads ();
   exit (EXIT_SUCCESS);
 #else /* HAVE_FORK */
   eprintf ("This version does not support fork", __FILE__, __LINE__);
+  /* Ignoring, as Check is not compiled with fork support. */
+  exit (EXIT_FAILURE);
 #endif /* HAVE_FORK */
 }
