@@ -78,11 +78,9 @@ GType gst_trigger_control_source_get_type (void);
 /* Functions */
 
 GST_CONTROLLER_API
-GstControlSource *gst_trigger_control_source_new (void);
+GstControlSource *gst_trigger_control_source_new (void) G_GNUC_WARN_UNUSED_RESULT;
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstTriggerControlSource, gst_object_unref)
-#endif
 
 G_END_DECLS
 
