@@ -183,7 +183,7 @@ setup_sink_pad (GstElement * element, GstStaticPadTemplate * tmpl)
 
 /* set queue size to 2 buffers
  * pull 1 buffer
- * check over/underuns
+ * check over/underruns
  */
 GST_START_TEST (test_non_leaky_underrun)
 {
@@ -225,9 +225,9 @@ queue_overrun_link_and_activate (GstElement * queue, gpointer user_data)
 
 /* set queue size to 2 buffers
  * push 2 buffers
- * check over/underuns
+ * check over/underruns
  * push 1 more buffer
- * check over/underuns again
+ * check over/underruns again
  */
 GST_START_TEST (test_non_leaky_overrun)
 {
@@ -320,9 +320,9 @@ GST_END_TEST;
 
 /* set queue size to 2 buffers
  * push 2 buffers
- * check over/underuns
+ * check over/underruns
  * push 1 more buffer
- * check over/underuns again
+ * check over/underruns again
  * check which buffer was leaked
  */
 GST_START_TEST (test_leaky_upstream)
@@ -409,9 +409,9 @@ GST_END_TEST;
 
 /* set queue size to 2 buffers
  * push 2 buffers
- * check over/underuns
+ * check over/underruns
  * push 1 more buffer
- * check over/underuns again
+ * check over/underruns again
  * check which buffer was leaked
  */
 GST_START_TEST (test_leaky_downstream)
@@ -532,20 +532,19 @@ GST_START_TEST (test_time_level)
   /* pushing gives away my reference */
   gst_pad_push (mysrcpad, buffer);
 
-  /* level should be 1 seconds because buffer has no duration and starts at 1
-   * SECOND (sparse stream). */
+  /* level should be zero because buffer has no duration */
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != GST_SECOND);
+  fail_if (time != 0);
 
-  /* second push should set the level to 2 second */
+  /* second push should set the level to 1 second */
   buffer = gst_buffer_new_and_alloc (4);
   GST_BUFFER_TIMESTAMP (buffer) = 2 * GST_SECOND;
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 2 * GST_SECOND);
+  fail_if (time != GST_SECOND);
 
-  /* third push should set the level to 4 seconds, the 1 second diff with the
+  /* third push should set the level to 3 seconds, the 1 second diff with the
    * previous buffer (without duration) and the 1 second duration of this
    * buffer. */
   buffer = gst_buffer_new_and_alloc (4);
@@ -555,9 +554,9 @@ GST_START_TEST (test_time_level)
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 4 * GST_SECOND);
+  fail_if (time != 3 * GST_SECOND);
 
-  /* fourth push should set the level to 6 seconds, the 2 second diff with the
+  /* fourth push should set the level to 5 seconds, the 2 second diff with the
    * previous buffer, same duration. */
   buffer = gst_buffer_new_and_alloc (4);
   GST_BUFFER_TIMESTAMP (buffer) = 5 * GST_SECOND;
@@ -566,7 +565,7 @@ GST_START_TEST (test_time_level)
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 6 * GST_SECOND);
+  fail_if (time != 5 * GST_SECOND);
 
   /* fifth push should not adjust the level, the timestamp and duration are the
    * same, meaning the previous buffer did not really have a duration. */
@@ -576,7 +575,7 @@ GST_START_TEST (test_time_level)
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 6 * GST_SECOND);
+  fail_if (time != 5 * GST_SECOND);
 
   /* sixth push should adjust the level with 1 second, we now know the
    * previous buffer actually had a duration of 2 SECONDS */
@@ -585,7 +584,7 @@ GST_START_TEST (test_time_level)
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 7 * GST_SECOND);
+  fail_if (time != 6 * GST_SECOND);
 
   /* eighth push should cause overrun */
   fail_unless (overrun_count == 0);
@@ -635,7 +634,7 @@ GST_START_TEST (test_time_level_task_not_started)
   gst_pad_push_event (mysrcpad, event);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_if (time != 0 * GST_SECOND);
+  fail_if (time != 0);
 
   segment.base = 4 * GST_SECOND;
   event = gst_event_new_segment (&segment);
@@ -643,7 +642,7 @@ GST_START_TEST (test_time_level_task_not_started)
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
   GST_DEBUG ("time now %" GST_TIME_FORMAT, GST_TIME_ARGS (time));
-  fail_if (time != 4 * GST_SECOND);
+  fail_if (time != 0);
 
   unblock_src ();
 
@@ -1018,10 +1017,9 @@ GST_START_TEST (test_time_level_buffer_list)
   /* pushing gives away my reference */
   gst_pad_push (mysrcpad, buffer);
 
-  /* level should be 1 seconds because buffer has no duration and starts at 1
-   * SECOND (sparse stream). */
+  /* level should be zero because buffer has no duration */
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 1000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 0);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 1);
 
@@ -1036,11 +1034,11 @@ GST_START_TEST (test_time_level_buffer_list)
   gst_pad_push_list (mysrcpad, buffer_list);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 2000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 1000 * GST_MSECOND);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 3);
 
-  /* third push should set the level to 4 seconds, the 1 second diff with the
+  /* third push should set the level to 3 seconds, the 1 second diff with the
    * previous buffer (without duration) and the 1 second duration of this
    * buffer. */
   buffer_list = gst_buffer_list_new ();
@@ -1057,11 +1055,11 @@ GST_START_TEST (test_time_level_buffer_list)
   gst_pad_push_list (mysrcpad, buffer_list);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 4000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 3000 * GST_MSECOND);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 5);
 
-  /* fourth push should set the level to 6 seconds, the 2 second diff with the
+  /* fourth push should set the level to 5 seconds, the 2 second diff with the
    * previous buffer, same duration. */
   buffer_list = gst_buffer_list_new ();
   buffer = gst_buffer_new_and_alloc (4);
@@ -1072,7 +1070,7 @@ GST_START_TEST (test_time_level_buffer_list)
   gst_pad_push_list (mysrcpad, buffer_list);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 6000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 5000 * GST_MSECOND);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 6);
 
@@ -1098,7 +1096,7 @@ GST_START_TEST (test_time_level_buffer_list)
   gst_pad_push_list (mysrcpad, buffer_list);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 6000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 5000 * GST_MSECOND);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 10);
 
@@ -1109,7 +1107,7 @@ GST_START_TEST (test_time_level_buffer_list)
   gst_pad_push (mysrcpad, buffer);
 
   g_object_get (G_OBJECT (queue), "current-level-time", &time, NULL);
-  fail_unless_equals_uint64 (time, 7000 * GST_MSECOND);
+  fail_unless_equals_uint64 (time, 6000 * GST_MSECOND);
   g_object_get (G_OBJECT (queue), "current-level-buffers", &buffers, NULL);
   fail_unless_equals_int (buffers, 11);
 
@@ -1181,6 +1179,208 @@ GST_START_TEST (test_initial_events_nodelay)
 
 GST_END_TEST;
 
+typedef struct
+{
+  GstBuffer *buffer;
+  GMutex lock;
+  GCond cond;
+  gboolean blocked;
+} FlushOnErrorData;
+
+static GstPadProbeReturn
+flush_on_error_block_probe (GstPad * pad, GstPadProbeInfo * info,
+    FlushOnErrorData * data)
+{
+  g_mutex_lock (&data->lock);
+  data->blocked = TRUE;
+  g_cond_signal (&data->cond);
+  g_mutex_unlock (&data->lock);
+
+  return GST_PAD_PROBE_OK;
+}
+
+static GstPadProbeReturn
+flush_on_error_probe (GstPad * pad, GstPadProbeInfo * info,
+    FlushOnErrorData * data)
+{
+  if (GST_IS_EVENT (GST_PAD_PROBE_INFO_DATA (info)))
+    return GST_PAD_PROBE_DROP;
+
+  g_mutex_lock (&data->lock);
+  data->buffer = GST_PAD_PROBE_INFO_BUFFER (info);
+  g_cond_signal (&data->cond);
+  g_mutex_unlock (&data->lock);
+
+  GST_PAD_PROBE_INFO_FLOW_RETURN (info) = GST_FLOW_ERROR;
+
+  return GST_PAD_PROBE_HANDLED;
+}
+
+static gpointer
+alloc_thread (GstBufferPool * pool)
+{
+  GstFlowReturn ret;
+  GstBuffer *buf;
+
+  /* This call will be blocked */
+  ret = gst_buffer_pool_acquire_buffer (pool, &buf, NULL);
+  fail_unless (ret == GST_FLOW_OK);
+
+  gst_buffer_unref (buf);
+
+  return NULL;
+}
+
+GST_START_TEST (test_flush_on_error)
+{
+  GstElement *elem;
+  GstPad *sinkpad;
+  GstPad *srcpad;
+  GstSegment segment;
+  GstCaps *caps;
+  gboolean ret;
+  gulong block_id;
+  FlushOnErrorData data;
+  GstBufferPool *pool;
+  GstStructure *config;
+  GstBuffer *buf;
+  GstFlowReturn flow_ret;
+  GThread *thread;
+
+  data.buffer = NULL;
+  data.blocked = FALSE;
+  g_mutex_init (&data.lock);
+  g_cond_init (&data.cond);
+
+  /* Setup bufferpool with max-buffers 2 */
+  caps = gst_caps_new_empty_simple ("foo/x-bar");
+  pool = gst_buffer_pool_new ();
+  config = gst_buffer_pool_get_config (pool);
+  gst_buffer_pool_config_set_params (config, caps, 4, 0, 2);
+  gst_buffer_pool_set_config (pool, config);
+  gst_buffer_pool_set_active (pool, TRUE);
+
+  elem = gst_element_factory_make ("queue", NULL);
+  gst_object_ref_sink (elem);
+  sinkpad = gst_element_get_static_pad (elem, "sink");
+  srcpad = gst_element_get_static_pad (elem, "src");
+
+  block_id = gst_pad_add_probe (srcpad,
+      GST_PAD_PROBE_TYPE_BLOCK | GST_PAD_PROBE_TYPE_BUFFER,
+      (GstPadProbeCallback) flush_on_error_block_probe, &data, NULL);
+  gst_pad_add_probe (srcpad,
+      GST_PAD_PROBE_TYPE_EVENT_DOWNSTREAM | GST_PAD_PROBE_TYPE_BUFFER,
+      (GstPadProbeCallback) flush_on_error_probe, &data, NULL);
+
+  fail_unless (gst_element_set_state (elem,
+          GST_STATE_PLAYING) == GST_STATE_CHANGE_SUCCESS,
+      "could not set to playing");
+
+  ret = gst_pad_send_event (sinkpad,
+      gst_event_new_stream_start ("test-stream-start"));
+  fail_unless (ret);
+
+  ret = gst_pad_send_event (sinkpad, gst_event_new_caps (caps));
+  gst_caps_unref (caps);
+  fail_unless (ret);
+
+  gst_segment_init (&segment, GST_FORMAT_TIME);
+  ret = gst_pad_send_event (sinkpad, gst_event_new_segment (&segment));
+  fail_unless (ret);
+
+  flow_ret = gst_buffer_pool_acquire_buffer (pool, &buf, NULL);
+  fail_unless (flow_ret == GST_FLOW_OK);
+  GST_BUFFER_PTS (buf) = 0;
+  flow_ret = gst_pad_chain (sinkpad, buf);
+  fail_unless (flow_ret == GST_FLOW_OK);
+
+  flow_ret = gst_buffer_pool_acquire_buffer (pool, &buf, NULL);
+  fail_unless (flow_ret == GST_FLOW_OK);
+  GST_BUFFER_PTS (buf) = GST_SECOND;
+  flow_ret = gst_pad_chain (sinkpad, buf);
+  fail_unless (flow_ret == GST_FLOW_OK);
+
+  /* Acquire buffer from other thread. The acquire_buffer() will be blocked
+   * due to max-buffers 2 */
+  thread = g_thread_new (NULL, (GThreadFunc) alloc_thread, pool);
+
+  g_mutex_lock (&data.lock);
+  while (!data.blocked)
+    g_cond_wait (&data.cond, &data.lock);
+  g_mutex_unlock (&data.lock);
+
+  gst_pad_remove_probe (srcpad, block_id);
+
+  /* Then now acquire thread can be unblocked since queue will flush
+   * internal queue on flow error */
+  g_thread_join (thread);
+
+  gst_element_set_state (elem, GST_STATE_NULL);
+  gst_clear_buffer (&data.buffer);
+  gst_buffer_pool_set_active (pool, FALSE);
+  gst_object_unref (pool);
+  gst_object_unref (sinkpad);
+  gst_object_unref (srcpad);
+  gst_object_unref (elem);
+  g_mutex_clear (&data.lock);
+  g_cond_clear (&data.cond);
+}
+
+GST_END_TEST;
+
+GST_START_TEST (test_time_level_before_output)
+{
+  GstBuffer *buffer1;
+  GstBuffer *buffer2;
+  GstSegment segment;
+  GstClockTime time;
+
+  g_signal_connect (queue, "overrun", G_CALLBACK (queue_overrun), NULL);
+  g_object_set (queue, "max-size-time", 5 * GST_SECOND, "leaky", 2, NULL);
+
+  block_src ();
+
+  UNDERRUN_LOCK ();
+  fail_unless (gst_element_set_state (queue,
+          GST_STATE_PLAYING) == GST_STATE_CHANGE_SUCCESS,
+      "could not set to playing");
+  UNDERRUN_WAIT ();
+  UNDERRUN_UNLOCK ();
+
+  gst_segment_init (&segment, GST_FORMAT_BYTES);
+  gst_pad_push_event (mysrcpad, gst_event_new_stream_start ("test"));
+  gst_pad_push_event (mysrcpad, gst_event_new_segment (&segment));
+
+  fail_unless_equals_int (overrun_count, 0);
+  fail_unless_equals_int (underrun_count, 1);
+
+  buffer1 = gst_buffer_new_and_alloc (4);
+  GST_BUFFER_TIMESTAMP (buffer1) = 25 * GST_SECOND;
+  GST_BUFFER_DURATION (buffer1) = GST_SECOND;
+  gst_pad_push (mysrcpad, buffer1);
+
+  /* Pushed 1 second duration buffer, should report 1 seconds */
+  g_object_get (queue, "current-level-time", &time, NULL);
+  fail_unless_equals_int64 (time, GST_SECOND);
+  fail_unless_equals_int (overrun_count, 0);
+  fail_unless_equals_int (underrun_count, 1);
+
+  buffer2 = gst_buffer_new_and_alloc (4);
+  gst_pad_push (mysrcpad, buffer2);
+
+  /* Pushed with unknown duration, should not cause overrun and
+   * timelevel should not be changed */
+  g_object_get (queue, "current-level-time", &time, NULL);
+  fail_unless_equals_int64 (time, GST_SECOND);
+  fail_unless_equals_int (overrun_count, 0);
+  fail_unless_equals_int (underrun_count, 1);
+
+  fail_unless (gst_element_set_state (queue,
+          GST_STATE_NULL) == GST_STATE_CHANGE_SUCCESS, "could not set to null");
+}
+
+GST_END_TEST;
+
 static Suite *
 queue_suite (void)
 {
@@ -1204,6 +1404,8 @@ queue_suite (void)
   tcase_add_test (tc_chain, test_sticky_not_linked);
   tcase_add_test (tc_chain, test_time_level_buffer_list);
   tcase_add_test (tc_chain, test_initial_events_nodelay);
+  tcase_add_test (tc_chain, test_flush_on_error);
+  tcase_add_test (tc_chain, test_time_level_before_output);
 
   return s;
 }
