@@ -1145,6 +1145,207 @@ GST_START_TEST (test_intersect_flagset)
 
 GST_END_TEST;
 
+GST_START_TEST (test_intersect_caps_set_in_caps)
+{
+  GstCaps *superset, *subset, *intersect, *expected_intersect;
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  expected_intersect = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  /* *INDENT-ON* */
+
+  /* Check simple intersect */
+  fail_unless (gst_caps_can_intersect (subset, superset));
+
+  intersect = gst_caps_intersect (superset, subset);
+
+  fail_unless (gst_caps_is_equal (intersect, expected_intersect));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+  gst_caps_unref (intersect);
+  gst_caps_unref (expected_intersect);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[5, 10]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32;"
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  expected_intersect = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  /* *INDENT-ON* */
+
+  /* Check intersect with multi-structure */
+  fail_unless (gst_caps_can_intersect (subset, superset));
+
+  intersect = gst_caps_intersect (superset, subset);
+
+  fail_unless (gst_caps_is_equal (intersect, expected_intersect));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+  gst_caps_unref (intersect);
+  gst_caps_unref (expected_intersect);
+
+
+}
+
+GST_END_TEST;
+
+GST_START_TEST (test_intersect_set)
+{
+  GstCaps *superset, *subset, *intersect, *expected_intersect;
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[5, 10]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ], ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+  "       dims-order = (string)row-major,"
+  "       type = (string)float32"
+  "   ]"
+  "}"
+);
+
+subset = gst_caps_from_string (
+  "video/x-raw,"
+  " width = 10,"
+  " tensors = (caps/set) {"
+  "   ["
+  "     tensor/strided,"
+  "       tensor-id = tensor-a,"
+  "       dims = <(int)3>,"
+  "       dims-order = (string)row-major,"
+  "       type = (string)float32"
+  "   ]"
+  "}"
+);
+
+expected_intersect = gst_caps_from_string (
+  "video/x-raw,"
+  " width = 10,"
+  " tensors = (caps/set) {"
+  "   ["
+  "     tensor/strided,"
+  "       tensor-id = tensor-a,"
+  "       dims = <(int)3>,"
+  "       dims-order = (string)row-major,"
+  "       type = (string)float32"
+  "   ]"
+  "}"
+);
+
+/* *INDENT-ON* */
+
+/* Check intersect set where only one element of set match */
+  fail_unless (gst_caps_can_intersect (subset, superset));
+
+  intersect = gst_caps_intersect (superset, subset);
+
+  fail_unless (gst_caps_is_equal (intersect, expected_intersect));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+  gst_caps_unref (intersect);
+  gst_caps_unref (expected_intersect);
+
+}
+
+GST_END_TEST;
+
+
+
 GST_START_TEST (test_union)
 {
   GstCaps *c1, *c2, *test, *expect;
@@ -1886,6 +2087,45 @@ GST_START_TEST (test_fixed)
       ("video/x-raw, tensor = (GstCaps)[tensor/strided, dims=<0, 5>]");
   fail_unless (gst_caps_is_fixed (caps));
   gst_caps_unref (caps);
+
+  /* *INDENT-OFF* */
+  caps = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  fail_if (gst_caps_is_fixed (caps));
+  gst_caps_unref (caps);
+
+  /* *INDENT-OFF* */
+  caps = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)1>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  fail_unless (gst_caps_is_fixed (caps));
+  gst_caps_unref (caps);
+
 }
 
 GST_END_TEST;
@@ -2030,6 +2270,331 @@ GST_START_TEST (test_array_subset)
 
 GST_END_TEST;
 
+GST_START_TEST (test_caps_in_set_in_caps_subset)
+{
+  GstCaps *superset, *subset;
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+/* Check simple subset */
+  fail_unless (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)10>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check we non-subset are found */
+  fail_if (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32;"
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[5, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)10>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check superset with alternative option work */
+  fail_unless (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-b,"
+    "       dims = <(int)[1, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)10>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check one field not matching */
+  fail_if (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       dims = <(int)10>,"
+    "       tensor-id = tensor-a,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check order of field have not impact */
+  fail_unless (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ], ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-b,"
+    "       dims = <(int)[1, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)10>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check that  superset 'set' contain subset 'set' and more. */
+  fail_unless (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ], ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-b,"
+    "       dims = <(int)[1, 15]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ], ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-b,"
+    "       dims = <(int)7>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* multiple element in the set */
+  fail_unless (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+  /* *INDENT-OFF* */
+  superset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)[1, 5]>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+
+  subset = gst_caps_from_string (
+    "video/x-raw,"
+    " width = 10,"
+    " tensors = (caps/set) {"
+    "   ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-a,"
+    "       dims = <(int)3>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ], ["
+    "     tensor/strided,"
+    "       tensor-id = tensor-b,"
+    "       dims = <(int)7>,"
+    "       dims-order = (string)row-major,"
+    "       type = (string)float32"
+    "   ]"
+    "}"
+  );
+  /* *INDENT-ON* */
+
+  /* Check of subset contain more then superset */
+  fail_if (gst_caps_is_subset (subset, superset));
+
+  gst_caps_unref (superset);
+  gst_caps_unref (subset);
+
+}
+
+GST_END_TEST;
+
 
 static Suite *
 gst_caps_suite (void)
@@ -2058,6 +2623,8 @@ gst_caps_suite (void)
   tcase_add_test (tc_chain, test_intersect_first2);
   tcase_add_test (tc_chain, test_intersect_duplication);
   tcase_add_test (tc_chain, test_intersect_flagset);
+  tcase_add_test (tc_chain, test_intersect_set);
+  tcase_add_test (tc_chain, test_intersect_caps_set_in_caps);
   tcase_add_test (tc_chain, test_union);
   tcase_add_test (tc_chain, test_normalize);
   tcase_add_test (tc_chain, test_broken);
@@ -2071,6 +2638,7 @@ gst_caps_suite (void)
   tcase_add_test (tc_chain, test_fixed);
   tcase_add_test (tc_chain, test_nested);
   tcase_add_test (tc_chain, test_array_subset);
+  tcase_add_test (tc_chain, test_caps_in_set_in_caps_subset);
 
   return s;
 }
