@@ -1169,6 +1169,61 @@ GST_START_TEST (test_strict)
 
 GST_END_TEST;
 
+GST_START_TEST (test_strv)
+{
+  GstStructure *s;
+  const gchar *strv[] = { "foo", " ,<>\" ", NULL };
+
+  s = gst_structure_new ("test-struct", "strv", G_TYPE_STRV, strv, NULL);
+  fail_unless (s);
+
+  gchar *serialized = gst_structure_serialize_full (s, GST_SERIALIZE_FLAG_NONE);
+  fail_unless (serialized);
+  gst_structure_free (s);
+
+  s = gst_structure_new_from_string (serialized);
+  fail_unless (s);
+  g_free (serialized);
+
+  gchar **out_strv = NULL;
+  fail_unless (gst_structure_get (s, "strv", G_TYPE_STRV, &out_strv, NULL));
+  fail_unless (g_strv_equal (strv, (const gchar * const *) out_strv));
+  gst_structure_free (s);
+  g_strfreev (out_strv);
+}
+
+GST_END_TEST;
+
+GST_START_TEST (test_container_type_marker)
+{
+  GstStructure *s;
+  const gchar expected[] = "root, f-set=(/set){ (int)1, (int)2 };";
+  gchar *res;
+  GValue vset = { 0 };
+  GValue v1 = { 0 }, v2 = { 0 };
+  s = gst_structure_new_empty ("root");
+  fail_unless (s);
+
+  g_value_init (&vset, GST_TYPE_SET);
+  g_value_init (&v1, G_TYPE_INT);
+  g_value_init (&v2, G_TYPE_INT);
+  g_value_set_int (&v1, 1);
+  g_value_set_int (&v2, 2);
+
+  gst_value_set_append_and_take_value (&vset, &v1);
+  gst_value_set_append_and_take_value (&vset, &v2);
+  gst_structure_take_value (s, "f-set", &vset);
+
+  res = gst_structure_serialize_full (s, GST_SERIALIZE_FLAG_NONE);
+  fail_unless (g_strcmp0 (expected, res) == 0);
+
+  gst_structure_free (s);
+
+  g_free (res);
+}
+
+GST_END_TEST;
+
 static Suite *
 gst_structure_suite (void)
 {
@@ -1203,6 +1258,8 @@ gst_structure_suite (void)
   tcase_add_test (tc_chain, test_flagset);
   tcase_add_test (tc_chain, test_flags);
   tcase_add_test (tc_chain, test_strict);
+  tcase_add_test (tc_chain, test_strv);
+  tcase_add_test (tc_chain, test_container_type_marker);
   return s;
 }
 
