@@ -181,22 +181,63 @@ n_print (const char *format, ...)
   g_free (str);
 }
 
+static void print_caps (const GstCaps * caps, const gchar * pfx,
+    const gchar * fieldname);
+
+static gboolean
+holds_long_type (const GValue * v)
+{
+  return GST_VALUE_HOLDS_CAPS (v) || GST_VALUE_HOLDS_STRUCTURE (v);
+}
+
+
 static gboolean
 print_field (const GstIdStr * fieldname, const GValue * value, gpointer pfx)
 {
-  gchar *str = gst_value_serialize (value);
   const gchar *type_name = g_type_name (G_VALUE_TYPE (value));
 
-  n_print ("%s  %s%15s%s: %s%s%s %s(%s)%s\n",
-      (gchar *) pfx, FIELD_NAME_COLOR, gst_id_str_as_str (fieldname),
-      RESET_COLOR, FIELD_VALUE_COLOR, str, RESET_COLOR,
-      DATATYPE_COLOR, type_name, RESET_COLOR);
-  g_free (str);
+  if (G_VALUE_HOLDS (value, GST_TYPE_SET) && gst_value_set_get_size (value) > 0) {
+    if (holds_long_type (gst_value_set_get_value (value, 0))) {
+      guint i;
+      gchar *pfx2 = g_strdup_printf ("%s  ", (gchar *) pfx);
+
+      n_print ("%s%s%s:%s (GstSet)\n", (gchar *) pfx, FIELD_VALUE_COLOR,
+          gst_id_str_as_str (fieldname), RESET_COLOR);
+      for (i = 0; i < gst_value_set_get_size (value); i++) {
+        const GValue *ivalue = gst_value_set_get_value (value, i);
+        print_caps (gst_value_get_caps (ivalue), pfx2, "");
+      }
+      g_free (pfx2);
+    }
+    return TRUE;
+  }
+
+  if (G_VALUE_HOLDS (value, GST_TYPE_CAPS)) {
+    gchar *pfx2 = g_strdup_printf ("%s  ", (gchar *) pfx);
+    print_caps (gst_value_get_caps (value), pfx2,
+        gst_id_str_as_str (fieldname));
+    g_free (pfx2);
+  } else if (G_VALUE_HOLDS (value, GST_TYPE_STRUCTURE)) {
+    const GstStructure *structure = gst_value_get_structure (value);
+    gchar *pfx2 = g_strdup_printf ("%s    ", (gchar *) pfx);
+    n_print ("%s  %s%s: %s%s%s (GstStructure)\n", (gchar *) pfx,
+        FIELD_NAME_COLOR, gst_id_str_as_str (fieldname), STRUCT_NAME_COLOR,
+        gst_structure_get_name (structure), RESET_COLOR);
+    gst_structure_foreach_id_str (structure, print_field, pfx2);
+    g_free (pfx2);
+  } else {
+    gchar *str = gst_value_serialize (value);
+    n_print ("%s  %s%15s%s: %s%s%s %s(%s)%s\n",
+        (gchar *) pfx, FIELD_NAME_COLOR, gst_id_str_as_str (fieldname),
+        RESET_COLOR, FIELD_VALUE_COLOR, str, RESET_COLOR,
+        DATATYPE_COLOR, type_name, RESET_COLOR);
+    g_free (str);
+  }
   return TRUE;
 }
 
 static void
-print_caps (const GstCaps * caps, const gchar * pfx)
+print_caps (const GstCaps * caps, const gchar * pfx, const gchar * fieldname)
 {
   guint i;
 
@@ -220,13 +261,14 @@ print_caps (const GstCaps * caps, const gchar * pfx)
                 GST_CAPS_FEATURES_MEMORY_SYSTEM_MEMORY))) {
       gchar *features_string = gst_caps_features_to_string (features);
 
-      n_print ("%s%s%s%s(%s%s%s)\n", pfx, STRUCT_NAME_COLOR,
+      n_print ("%s%s%s%s%s%s(%s%s%s)\n", pfx, FIELD_NAME_COLOR, fieldname,
+          STRUCT_NAME_COLOR,
           gst_structure_get_name (structure), RESET_COLOR,
           CAPS_FEATURE_COLOR, features_string, RESET_COLOR);
       g_free (features_string);
     } else {
-      n_print ("%s%s%s%s\n", pfx, STRUCT_NAME_COLOR,
-          gst_structure_get_name (structure), RESET_COLOR);
+      n_print ("%s%s%s%s%s%s\n", pfx, FIELD_NAME_COLOR, fieldname,
+          STRUCT_NAME_COLOR, gst_structure_get_name (structure), RESET_COLOR);
     }
     gst_structure_foreach_id_str (structure, print_field, (gpointer) pfx);
   }
@@ -681,7 +723,7 @@ print_object_properties_info (GObject * obj, GObjectClass * obj_class,
           if (!caps)
             n_print ("%sCaps%s (NULL)", DATATYPE_COLOR, RESET_COLOR);
           else {
-            print_caps (caps, "                           ");
+            print_caps (caps, "                           ", "");
           }
         } else if (G_IS_PARAM_SPEC_ENUM (param)) {
           GEnumValue *values;
@@ -902,7 +944,7 @@ print_pad_templates_info (GstElement * element, GstElementFactory * factory)
       n_print ("%sCapabilities%s:\n", PROP_NAME_COLOR, RESET_COLOR);
 
       push_indent ();
-      print_caps (caps, "");    // FIXME
+      print_caps (caps, "", "");        // FIXME
       pop_indent ();
 
       gst_caps_unref (caps);
